#ifndef _HOME_SKEGGSB_GIT_ENVYTOOLS_RNNDB_NV50_3D_XML
#define _HOME_SKEGGSB_GIT_ENVYTOOLS_RNNDB_NV50_3D_XML

/* Autogenerated file, DO NOT EDIT manually!

This file was generated by the rules-ng-ng headergen tool in this git repository:
http://0x04.net/cgit/index.cgi/rules-ng-ng
git clone git://0x04.net/rules-ng-ng

The rules-ng-ng source files this header was generated from are:
- /home/skeggsb/git/envytools/rnndb/nv_objects.xml      (    794 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/copyright.xml       (   6452 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv_m2mf.xml         (   2696 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv_object.xml       (  12672 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nvchipsets.xml      (   3617 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv_defs.xml         (   4437 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv50_defs.xml       (   5468 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nvc0_m2mf.xml       (   2687 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv01_2d.xml         (  32584 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv04_dvd.xml        (   3000 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv03_3d.xml         (   5209 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv04_3d.xml         (  17759 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv_3ddefs.xml       (  16394 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv10_3d.xml         (  18437 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv20_3d.xml         (  21107 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv30-40_3d.xml      (  31987 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv50_2d.xml         (  11113 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv50_3d.xml         (  65233 bytes, from 2011-11-30 05:49:35)
- /home/skeggsb/git/envytools/rnndb/nv50_compute.xml    (  14012 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nv84_crypt.xml      (   2071 bytes, from 2011-11-30 05:49:35)
- /home/skeggsb/git/envytools/rnndb/nv31_mpeg.xml       (   2269 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/nvc0_3d.xml         (  52547 bytes, from 2011-11-30 05:49:35)
- /home/skeggsb/git/envytools/rnndb/nvc0_compute.xml    (  10865 bytes, from 2011-10-22 08:01:09)
- /home/skeggsb/git/envytools/rnndb/blob_nvc0_pcopy.xml (   4516 bytes, from 2011-10-22 08:01:09)

Copyright (C) 2006-2011 by the following authors:
- Artur Huillet <arthur.huillet@free.fr> (ahuillet)
- Ben Skeggs (darktama, darktama_)
- B. R. <koala_br@users.sourceforge.net> (koala_br)
- Carlos Martin <carlosmn@users.sf.net> (carlosmn)
- Christoph Bumiller <e0425955@student.tuwien.ac.at> (calim, chrisbmr)
- Dawid Gajownik <gajownik@users.sf.net> (gajownik)
- Dmitry Baryshkov
- Dmitry Eremin-Solenikov <lumag@users.sf.net> (lumag)
- EdB <edb_@users.sf.net> (edb_)
- Erik Waling <erikwailing@users.sf.net> (erikwaling)
- Francisco Jerez <currojerez@riseup.net> (curro)
- imirkin <imirkin@users.sf.net> (imirkin)
- jb17bsome <jb17bsome@bellsouth.net> (jb17bsome)
- Jeremy Kolb <kjeremy@users.sf.net> (kjeremy)
- Laurent Carlier <lordheavym@gmail.com> (lordheavy)
- Luca Barbieri <luca@luca-barbieri.com> (lb, lb1)
- Maarten Maathuis <madman2003@gmail.com> (stillunknown)
- Marcin Kościelnicki <koriakin@0x04.net> (mwk, koriakin)
- Mark Carey <mark.carey@gmail.com> (careym)
- Matthieu Castet <matthieu.castet@parrot.com> (mat-c)
- nvidiaman <nvidiaman@users.sf.net> (nvidiaman)
- Patrice Mandin <patmandin@gmail.com> (pmandin, pmdata)
- Pekka Paalanen <pq@iki.fi> (pq, ppaalanen)
- Peter Popov <ironpeter@users.sf.net> (ironpeter)
- Richard Hughes <hughsient@users.sf.net> (hughsient)
- Rudi Cilibrasi <cilibrar@users.sf.net> (cilibrar)
- Serge Martin
- Simon Raffeiner
- Stephane Loeuillet <leroutier@users.sf.net> (leroutier)
- Stephane Marchesin <stephane.marchesin@gmail.com> (marcheu)
- sturmflut <sturmflut@users.sf.net> (sturmflut)
- Sylvain Munaut <tnt@246tNt.com>
- Victor Stinner <victor.stinner@haypocalc.com> (haypo)
- Wladmir van der Laan <laanwj@gmail.com> (miathan6)
- Younes Manton <younes.m@gmail.com> (ymanton)

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice (including the
next paragraph) shall be included in all copies or substantial
portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE COPYRIGHT OWNER(S) AND/OR ITS SUPPLIERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/



#define NV50_3D_DMA_NOTIFY					0x00000180

#define NV50_3D_DMA_ZETA					0x00000184

#define NV50_3D_DMA_QUERY					0x00000188

#define NV50_3D_DMA_VTXBUF					0x0000018c

#define NV50_3D_DMA_LOCAL					0x00000190

#define NV50_3D_DMA_STACK					0x00000194

#define NV50_3D_DMA_CODE_CB					0x00000198

#define NV50_3D_DMA_TSC						0x0000019c

#define NV50_3D_DMA_TIC						0x000001a0

#define NV50_3D_DMA_TEXTURE					0x000001a4

#define NV50_3D_DMA_STRMOUT					0x000001a8

#define NV50_3D_DMA_CLIPID					0x000001ac

#define NV50_3D_DMA_COLOR(i0)				       (0x000001c0 + 0x4*(i0))
#define NV50_3D_DMA_COLOR__ESIZE				0x00000004
#define NV50_3D_DMA_COLOR__LEN					0x00000008

#define NV50_3D_RT(i0)					       (0x00000200 + 0x20*(i0))
#define NV50_3D_RT__ESIZE					0x00000020
#define NV50_3D_RT__LEN						0x00000008

#define NV50_3D_RT_ADDRESS_HIGH(i0)			       (0x00000200 + 0x20*(i0))

#define NV50_3D_RT_ADDRESS_LOW(i0)			       (0x00000204 + 0x20*(i0))

#define NV50_3D_RT_FORMAT(i0)				       (0x00000208 + 0x20*(i0))

#define NV50_3D_RT_TILE_MODE(i0)			       (0x0000020c + 0x20*(i0))
#define NV50_3D_RT_TILE_MODE_X__MASK				0x0000000f
#define NV50_3D_RT_TILE_MODE_X__SHIFT				0
#define NV50_3D_RT_TILE_MODE_Y__MASK				0x000000f0
#define NV50_3D_RT_TILE_MODE_Y__SHIFT				4
#define NV50_3D_RT_TILE_MODE_Z__MASK				0x00000f00
#define NV50_3D_RT_TILE_MODE_Z__SHIFT				8

#define NV50_3D_RT_LAYER_STRIDE(i0)			       (0x00000210 + 0x20*(i0))
#define NV50_3D_RT_LAYER_STRIDE__SHR				2

#define NV50_3D_RT_UNK14(i0)				       (0x00000214 + 0x20*(i0))

#define NV50_3D_VTX_ATTR_1F(i0)				       (0x00000300 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_1F__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_1F__LEN				0x00000010

#define NV50_3D_VTX_ATTR_2H(i0)				       (0x00000340 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_2H__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_2H__LEN				0x00000010
#define NV50_3D_VTX_ATTR_2H_X__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_2H_X__SHIFT				0
#define NV50_3D_VTX_ATTR_2H_Y__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_2H_Y__SHIFT				16

#define NV50_3D_VTX_ATTR_2F_X(i0)			       (0x00000380 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_2F_X__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_2F_X__LEN				0x00000010

#define NV50_3D_VTX_ATTR_2F_Y(i0)			       (0x00000384 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_2F_Y__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_2F_Y__LEN				0x00000010

#define NV50_3D_VTX_ATTR_3F_X(i0)			       (0x00000400 + 0x10*(i0))
#define NV50_3D_VTX_ATTR_3F_X__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_3F_X__LEN				0x00000010

#define NV50_3D_VTX_ATTR_3F_Y(i0)			       (0x00000404 + 0x10*(i0))
#define NV50_3D_VTX_ATTR_3F_Y__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_3F_Y__LEN				0x00000010

#define NV50_3D_VTX_ATTR_3F_Z(i0)			       (0x00000408 + 0x10*(i0))
#define NV50_3D_VTX_ATTR_3F_Z__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_3F_Z__LEN				0x00000010

#define NV50_3D_VTX_ATTR_4F_X(i0)			       (0x00000500 + 0x10*(i0))
#define NV50_3D_VTX_ATTR_4F_X__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_4F_X__LEN				0x00000010

#define NV50_3D_VTX_ATTR_4F_Y(i0)			       (0x00000504 + 0x10*(i0))
#define NV50_3D_VTX_ATTR_4F_Y__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_4F_Y__LEN				0x00000010

#define NV50_3D_VTX_ATTR_4F_Z(i0)			       (0x00000508 + 0x10*(i0))
#define NV50_3D_VTX_ATTR_4F_Z__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_4F_Z__LEN				0x00000010

#define NV50_3D_VTX_ATTR_4F_W(i0)			       (0x0000050c + 0x10*(i0))
#define NV50_3D_VTX_ATTR_4F_W__ESIZE				0x00000010
#define NV50_3D_VTX_ATTR_4F_W__LEN				0x00000010

#define NV50_3D_VTX_ATTR_4H_0(i0)			       (0x00000600 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_4H_0__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_4H_0__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4H_0_X__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_4H_0_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4H_0_Y__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_4H_0_Y__SHIFT				16

#define NV50_3D_VTX_ATTR_4H_1(i0)			       (0x00000604 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_4H_1__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_4H_1__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4H_1_Z__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_4H_1_Z__SHIFT				0
#define NV50_3D_VTX_ATTR_4H_1_W__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_4H_1_W__SHIFT				16

#define NV50_3D_VTX_ATTR_2I(i0)				       (0x00000680 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_2I__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_2I__LEN				0x00000010
#define NV50_3D_VTX_ATTR_2I_X__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_2I_X__SHIFT				0
#define NV50_3D_VTX_ATTR_2I_Y__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_2I_Y__SHIFT				16

#define NV50_3D_VTX_ATTR_2NI(i0)			       (0x000006c0 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_2NI__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_2NI__LEN				0x00000010
#define NV50_3D_VTX_ATTR_2NI_X__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_2NI_X__SHIFT				0
#define NV50_3D_VTX_ATTR_2NI_Y__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_2NI_Y__SHIFT				16

#define NV50_3D_VTX_ATTR_4I_0(i0)			       (0x00000700 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_4I_0__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_4I_0__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4I_0_X__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_4I_0_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4I_0_Y__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_4I_0_Y__SHIFT				16

#define NV50_3D_VTX_ATTR_4I_1(i0)			       (0x00000704 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_4I_1__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_4I_1__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4I_1_Z__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_4I_1_Z__SHIFT				0
#define NV50_3D_VTX_ATTR_4I_1_W__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_4I_1_W__SHIFT				16

#define NV50_3D_VTX_ATTR_4NI_0(i0)			       (0x00000780 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_4NI_0__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_4NI_0__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4NI_0_X__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_4NI_0_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4NI_0_Y__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_4NI_0_Y__SHIFT				16

#define NV50_3D_VTX_ATTR_4NI_1(i0)			       (0x00000784 + 0x8*(i0))
#define NV50_3D_VTX_ATTR_4NI_1__ESIZE				0x00000008
#define NV50_3D_VTX_ATTR_4NI_1__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4NI_1_Z__MASK				0x0000ffff
#define NV50_3D_VTX_ATTR_4NI_1_Z__SHIFT				0
#define NV50_3D_VTX_ATTR_4NI_1_W__MASK				0xffff0000
#define NV50_3D_VTX_ATTR_4NI_1_W__SHIFT				16

#define NV50_3D_VTX_ATTR_4UB(i0)			       (0x00000800 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_4UB__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_4UB__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4UB_X__MASK				0x000000ff
#define NV50_3D_VTX_ATTR_4UB_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4UB_Y__MASK				0x0000ff00
#define NV50_3D_VTX_ATTR_4UB_Y__SHIFT				8
#define NV50_3D_VTX_ATTR_4UB_Z__MASK				0x00ff0000
#define NV50_3D_VTX_ATTR_4UB_Z__SHIFT				16
#define NV50_3D_VTX_ATTR_4UB_W__MASK				0xff000000
#define NV50_3D_VTX_ATTR_4UB_W__SHIFT				24

#define NV50_3D_VTX_ATTR_4B(i0)				       (0x00000840 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_4B__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_4B__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4B_X__MASK				0x000000ff
#define NV50_3D_VTX_ATTR_4B_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4B_Y__MASK				0x0000ff00
#define NV50_3D_VTX_ATTR_4B_Y__SHIFT				8
#define NV50_3D_VTX_ATTR_4B_Z__MASK				0x00ff0000
#define NV50_3D_VTX_ATTR_4B_Z__SHIFT				16
#define NV50_3D_VTX_ATTR_4B_W__MASK				0xff000000
#define NV50_3D_VTX_ATTR_4B_W__SHIFT				24

#define NV50_3D_VTX_ATTR_4NUB(i0)			       (0x00000880 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_4NUB__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_4NUB__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4NUB_X__MASK				0x000000ff
#define NV50_3D_VTX_ATTR_4NUB_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4NUB_Y__MASK				0x0000ff00
#define NV50_3D_VTX_ATTR_4NUB_Y__SHIFT				8
#define NV50_3D_VTX_ATTR_4NUB_Z__MASK				0x00ff0000
#define NV50_3D_VTX_ATTR_4NUB_Z__SHIFT				16
#define NV50_3D_VTX_ATTR_4NUB_W__MASK				0xff000000
#define NV50_3D_VTX_ATTR_4NUB_W__SHIFT				24

#define NV50_3D_VTX_ATTR_4NB(i0)			       (0x000008c0 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_4NB__ESIZE				0x00000004
#define NV50_3D_VTX_ATTR_4NB__LEN				0x00000010
#define NV50_3D_VTX_ATTR_4NB_X__MASK				0x000000ff
#define NV50_3D_VTX_ATTR_4NB_X__SHIFT				0
#define NV50_3D_VTX_ATTR_4NB_Y__MASK				0x0000ff00
#define NV50_3D_VTX_ATTR_4NB_Y__SHIFT				8
#define NV50_3D_VTX_ATTR_4NB_Z__MASK				0x00ff0000
#define NV50_3D_VTX_ATTR_4NB_Z__SHIFT				16
#define NV50_3D_VTX_ATTR_4NB_W__MASK				0xff000000
#define NV50_3D_VTX_ATTR_4NB_W__SHIFT				24

#define NV50_3D_VERTEX_ARRAY_FETCH(i0)			       (0x00000900 + 0x10*(i0))
#define NV50_3D_VERTEX_ARRAY_FETCH__ESIZE			0x00000010
#define NV50_3D_VERTEX_ARRAY_FETCH__LEN				0x00000010
#define NV50_3D_VERTEX_ARRAY_FETCH_STRIDE__MASK			0x00000fff
#define NV50_3D_VERTEX_ARRAY_FETCH_STRIDE__SHIFT		0
#define NV50_3D_VERTEX_ARRAY_FETCH_ENABLE			0x20000000

#define NV50_3D_VERTEX_ARRAY_START_HIGH(i0)		       (0x00000904 + 0x10*(i0))
#define NV50_3D_VERTEX_ARRAY_START_HIGH__ESIZE			0x00000010
#define NV50_3D_VERTEX_ARRAY_START_HIGH__LEN			0x00000010

#define NV50_3D_VERTEX_ARRAY_START_LOW(i0)		       (0x00000908 + 0x10*(i0))
#define NV50_3D_VERTEX_ARRAY_START_LOW__ESIZE			0x00000010
#define NV50_3D_VERTEX_ARRAY_START_LOW__LEN			0x00000010

#define NV50_3D_VERTEX_ARRAY_DIVISOR(i0)		       (0x0000090c + 0x10*(i0))
#define NV50_3D_VERTEX_ARRAY_DIVISOR__ESIZE			0x00000010
#define NV50_3D_VERTEX_ARRAY_DIVISOR__LEN			0x00000010

#define NV50_3D_VIEWPORT_SCALE_X(i0)			       (0x00000a00 + 0x20*(i0))
#define NV50_3D_VIEWPORT_SCALE_X__ESIZE				0x00000020
#define NV50_3D_VIEWPORT_SCALE_X__LEN				0x00000010

#define NV50_3D_VIEWPORT_SCALE_Y(i0)			       (0x00000a04 + 0x20*(i0))
#define NV50_3D_VIEWPORT_SCALE_Y__ESIZE				0x00000020
#define NV50_3D_VIEWPORT_SCALE_Y__LEN				0x00000010

#define NV50_3D_VIEWPORT_SCALE_Z(i0)			       (0x00000a08 + 0x20*(i0))
#define NV50_3D_VIEWPORT_SCALE_Z__ESIZE				0x00000020
#define NV50_3D_VIEWPORT_SCALE_Z__LEN				0x00000010

#define NV50_3D_VIEWPORT_TRANSLATE_X(i0)		       (0x00000a0c + 0x20*(i0))
#define NV50_3D_VIEWPORT_TRANSLATE_X__ESIZE			0x00000020
#define NV50_3D_VIEWPORT_TRANSLATE_X__LEN			0x00000010

#define NV50_3D_VIEWPORT_TRANSLATE_Y(i0)		       (0x00000a10 + 0x20*(i0))
#define NV50_3D_VIEWPORT_TRANSLATE_Y__ESIZE			0x00000020
#define NV50_3D_VIEWPORT_TRANSLATE_Y__LEN			0x00000010

#define NV50_3D_VIEWPORT_TRANSLATE_Z(i0)		       (0x00000a14 + 0x20*(i0))
#define NV50_3D_VIEWPORT_TRANSLATE_Z__ESIZE			0x00000020
#define NV50_3D_VIEWPORT_TRANSLATE_Z__LEN			0x00000010

#define NV50_3D_VIEWPORT_HORIZ(i0)			       (0x00000c00 + 0x10*(i0))
#define NV50_3D_VIEWPORT_HORIZ__ESIZE				0x00000010
#define NV50_3D_VIEWPORT_HORIZ__LEN				0x00000010
#define NV50_3D_VIEWPORT_HORIZ_X__MASK				0x0000ffff
#define NV50_3D_VIEWPORT_HORIZ_X__SHIFT				0
#define NV50_3D_VIEWPORT_HORIZ_W__MASK				0xffff0000
#define NV50_3D_VIEWPORT_HORIZ_W__SHIFT				16

#define NV50_3D_VIEWPORT_VERT(i0)			       (0x00000c04 + 0x10*(i0))
#define NV50_3D_VIEWPORT_VERT__ESIZE				0x00000010
#define NV50_3D_VIEWPORT_VERT__LEN				0x00000010
#define NV50_3D_VIEWPORT_VERT_Y__MASK				0x0000ffff
#define NV50_3D_VIEWPORT_VERT_Y__SHIFT				0
#define NV50_3D_VIEWPORT_VERT_H__MASK				0xffff0000
#define NV50_3D_VIEWPORT_VERT_H__SHIFT				16

#define NV50_3D_DEPTH_RANGE_NEAR(i0)			       (0x00000c08 + 0x10*(i0))
#define NV50_3D_DEPTH_RANGE_NEAR__ESIZE				0x00000010
#define NV50_3D_DEPTH_RANGE_NEAR__LEN				0x00000010

#define NV50_3D_DEPTH_RANGE_FAR(i0)			       (0x00000c0c + 0x10*(i0))
#define NV50_3D_DEPTH_RANGE_FAR__ESIZE				0x00000010
#define NV50_3D_DEPTH_RANGE_FAR__LEN				0x00000010

#define NV50_3D_CLIP_RECT_HORIZ(i0)			       (0x00000d00 + 0x8*(i0))
#define NV50_3D_CLIP_RECT_HORIZ__ESIZE				0x00000008
#define NV50_3D_CLIP_RECT_HORIZ__LEN				0x00000008
#define NV50_3D_CLIP_RECT_HORIZ_MIN__MASK			0x0000ffff
#define NV50_3D_CLIP_RECT_HORIZ_MIN__SHIFT			0
#define NV50_3D_CLIP_RECT_HORIZ_MAX__MASK			0xffff0000
#define NV50_3D_CLIP_RECT_HORIZ_MAX__SHIFT			16

#define NV50_3D_CLIP_RECT_VERT(i0)			       (0x00000d04 + 0x8*(i0))
#define NV50_3D_CLIP_RECT_VERT__ESIZE				0x00000008
#define NV50_3D_CLIP_RECT_VERT__LEN				0x00000008
#define NV50_3D_CLIP_RECT_VERT_MIN__MASK			0x0000ffff
#define NV50_3D_CLIP_RECT_VERT_MIN__SHIFT			0
#define NV50_3D_CLIP_RECT_VERT_MAX__MASK			0xffff0000
#define NV50_3D_CLIP_RECT_VERT_MAX__SHIFT			16

#define NV50_3D_CLIPID_REGION_HORIZ(i0)			       (0x00000d40 + 0x8*(i0))
#define NV50_3D_CLIPID_REGION_HORIZ__ESIZE			0x00000008
#define NV50_3D_CLIPID_REGION_HORIZ__LEN			0x00000004
#define NV50_3D_CLIPID_REGION_HORIZ_X__MASK			0x0000ffff
#define NV50_3D_CLIPID_REGION_HORIZ_X__SHIFT			0
#define NV50_3D_CLIPID_REGION_HORIZ_W__MASK			0xffff0000
#define NV50_3D_CLIPID_REGION_HORIZ_W__SHIFT			16

#define NV50_3D_CLIPID_REGION_VERT(i0)			       (0x00000d44 + 0x8*(i0))
#define NV50_3D_CLIPID_REGION_VERT__ESIZE			0x00000008
#define NV50_3D_CLIPID_REGION_VERT__LEN				0x00000004
#define NV50_3D_CLIPID_REGION_VERT_Y__MASK			0x0000ffff
#define NV50_3D_CLIPID_REGION_VERT_Y__SHIFT			0
#define NV50_3D_CLIPID_REGION_VERT_H__MASK			0xffff0000
#define NV50_3D_CLIPID_REGION_VERT_H__SHIFT			16

#define NV50_3D_UNK0D60						0x00000d60

#define NV50_3D_UNK0D64						0x00000d64

#define NV50_3D_COUNTER_ENABLE					0x00000d68
#define NV50_3D_COUNTER_ENABLE_VFETCH_VERTICES			0x00000001
#define NV50_3D_COUNTER_ENABLE_VFETCH_PRIMITIVES		0x00000002
#define NV50_3D_COUNTER_ENABLE_VP_LAUNCHES			0x00000004
#define NV50_3D_COUNTER_ENABLE_GP_LAUNCHES			0x00000008
#define NV50_3D_COUNTER_ENABLE_GP_PRIMITIVES_OUT		0x00000010
#define NV50_3D_COUNTER_ENABLE_TRANSFORM_FEEDBACK		0x00000020
#define NV50_3D_COUNTER_ENABLE_GENERATED_PRIMITIVES		0x00000040
#define NV50_3D_COUNTER_ENABLE_RAST_PRIMITIVES_PRECLIP		0x00000080
#define NV50_3D_COUNTER_ENABLE_RAST_PRIMITIVES_POSTCLIP		0x00000100
#define NV50_3D_COUNTER_ENABLE_FP_PIXELS			0x00000200
#define NV84_3D_COUNTER_ENABLE_UNK0A				0x00000400

#define NV50_3D_UNK0D6C(i0)				       (0x00000d6c + 0x4*(i0))
#define NV50_3D_UNK0D6C__ESIZE					0x00000004
#define NV50_3D_UNK0D6C__LEN					0x00000002
#define NV50_3D_UNK0D6C_X__MASK					0x0000ffff
#define NV50_3D_UNK0D6C_X__SHIFT				0
#define NV50_3D_UNK0D6C_Y__MASK					0xffff0000
#define NV50_3D_UNK0D6C_Y__SHIFT				16

#define NV50_3D_VERTEX_BUFFER_FIRST				0x00000d74

#define NV50_3D_VERTEX_BUFFER_COUNT				0x00000d78

#define NV50_3D_UNK0D7C						0x00000d7c

#define NV50_3D_CLEAR_COLOR(i0)				       (0x00000d80 + 0x4*(i0))
#define NV50_3D_CLEAR_COLOR__ESIZE				0x00000004
#define NV50_3D_CLEAR_COLOR__LEN				0x00000004

#define NV50_3D_CLEAR_DEPTH					0x00000d90

#define NV50_3D_STACK_ADDRESS_HIGH				0x00000d94

#define NV50_3D_STACK_ADDRESS_LOW				0x00000d98

#define NV50_3D_STACK_SIZE_LOG					0x00000d9c

#define NV50_3D_CLEAR_STENCIL					0x00000da0

#define NV50_3D_STRMOUT_PARAMS_LATCH				0x00000da4

#define NV50_3D_STRMOUT_PRIMITIVE_LIMIT				0x00000da8

#define NV50_3D_POLYGON_MODE_FRONT				0x00000dac
#define NV50_3D_POLYGON_MODE_FRONT_POINT			0x00001b00
#define NV50_3D_POLYGON_MODE_FRONT_LINE				0x00001b01
#define NV50_3D_POLYGON_MODE_FRONT_FILL				0x00001b02

#define NV50_3D_POLYGON_MODE_BACK				0x00000db0
#define NV50_3D_POLYGON_MODE_BACK_POINT				0x00001b00
#define NV50_3D_POLYGON_MODE_BACK_LINE				0x00001b01
#define NV50_3D_POLYGON_MODE_BACK_FILL				0x00001b02

#define NV50_3D_POLYGON_SMOOTH_ENABLE				0x00000db4

#define NV50_3D_UNK0DB8						0x00000db8

#define NV50_3D_ZCULL_UNK0DBC					0x00000dbc
#define NV50_3D_ZCULL_UNK0DBC_UNK0				0x00000001
#define NV50_3D_ZCULL_UNK0DBC_UNK16__MASK			0x00030000
#define NV50_3D_ZCULL_UNK0DBC_UNK16__SHIFT			16

#define NV50_3D_POLYGON_OFFSET_POINT_ENABLE			0x00000dc0

#define NV50_3D_POLYGON_OFFSET_LINE_ENABLE			0x00000dc4

#define NV50_3D_POLYGON_OFFSET_FILL_ENABLE			0x00000dc8

#define NV50_3D_UNK0DCC						0x00000dcc

#define NV50_3D_VTX_ATTR_MASK_UNK0DD0(i0)		       (0x00000dd0 + 0x4*(i0))
#define NV50_3D_VTX_ATTR_MASK_UNK0DD0__ESIZE			0x00000004
#define NV50_3D_VTX_ATTR_MASK_UNK0DD0__LEN			0x00000002

#define NV50_3D_ZCULL_UNK0DD8					0x00000dd8
#define NV50_3D_ZCULL_UNK0DD8_UNK0__MASK			0x00000007
#define NV50_3D_ZCULL_UNK0DD8_UNK0__SHIFT			0
#define NVA3_3D_ZCULL_UNK0DD8_UNK9				0x00000200
#define NV50_3D_ZCULL_UNK0DD8_UNK16__MASK			0xffff0000
#define NV50_3D_ZCULL_UNK0DD8_UNK16__SHIFT			16

#define NV50_3D_UNK0DDC						0x00000ddc

#define NV50_3D_UNK0DE0						0x00000de0

#define NV50_3D_WATCHDOG_TIMER					0x00000de4

#define NV50_3D_UNK0DE8						0x00000de8

#define NV50_3D_UNK0DEC						0x00000dec

#define NV50_3D_UNK0DF0						0x00000df0
#define NV50_3D_UNK0DF0_UNK0					0x00000001
#define NV50_3D_UNK0DF0_UNK1__MASK				0x00000ff0
#define NV50_3D_UNK0DF0_UNK1__SHIFT				4

#define NV50_3D_UNK0DF4						0x00000df4

#define NV50_3D_WINDOW_OFFSET_X					0x00000df8

#define NV50_3D_WINDOW_OFFSET_Y					0x00000dfc

#define NV50_3D_SCISSOR_ENABLE(i0)			       (0x00000e00 + 0x10*(i0))
#define NV50_3D_SCISSOR_ENABLE__ESIZE				0x00000010
#define NV50_3D_SCISSOR_ENABLE__LEN				0x00000010

#define NV50_3D_SCISSOR_HORIZ(i0)			       (0x00000e04 + 0x10*(i0))
#define NV50_3D_SCISSOR_HORIZ__ESIZE				0x00000010
#define NV50_3D_SCISSOR_HORIZ__LEN				0x00000010
#define NV50_3D_SCISSOR_HORIZ_MIN__MASK				0x0000ffff
#define NV50_3D_SCISSOR_HORIZ_MIN__SHIFT			0
#define NV50_3D_SCISSOR_HORIZ_MAX__MASK				0xffff0000
#define NV50_3D_SCISSOR_HORIZ_MAX__SHIFT			16

#define NV50_3D_SCISSOR_VERT(i0)			       (0x00000e08 + 0x10*(i0))
#define NV50_3D_SCISSOR_VERT__ESIZE				0x00000010
#define NV50_3D_SCISSOR_VERT__LEN				0x00000010
#define NV50_3D_SCISSOR_VERT_MIN__MASK				0x0000ffff
#define NV50_3D_SCISSOR_VERT_MIN__SHIFT				0
#define NV50_3D_SCISSOR_VERT_MAX__MASK				0xffff0000
#define NV50_3D_SCISSOR_VERT_MAX__SHIFT				16

#define NV50_3D_CB_ADDR						0x00000f00
#define NV50_3D_CB_ADDR_ID__MASK				0x003fff00
#define NV50_3D_CB_ADDR_ID__SHIFT				8
#define NV50_3D_CB_ADDR_BUFFER__MASK				0x0000007f
#define NV50_3D_CB_ADDR_BUFFER__SHIFT				0

#define NV50_3D_CB_DATA(i0)				       (0x00000f04 + 0x4*(i0))
#define NV50_3D_CB_DATA__ESIZE					0x00000004
#define NV50_3D_CB_DATA__LEN					0x00000010

#define NV50_3D_LOCAL_WARPS_LOG_ALLOC				0x00000f44

#define NV50_3D_LOCAL_WARPS_NO_CLAMP				0x00000f48

#define NV50_3D_STACK_WARPS_LOG_ALLOC				0x00000f4c

#define NV50_3D_STACK_WARPS_NO_CLAMP				0x00000f50

#define NV50_3D_STENCIL_BACK_FUNC_REF				0x00000f54

#define NV50_3D_STENCIL_BACK_MASK				0x00000f58

#define NV50_3D_STENCIL_BACK_FUNC_MASK				0x00000f5c

#define NV50_3D_UNK0F60(i0)				       (0x00000f60 + 0x4*(i0))
#define NV50_3D_UNK0F60__ESIZE					0x00000004
#define NV50_3D_UNK0F60__LEN					0x00000004

#define NV50_3D_GP_ADDRESS_HIGH					0x00000f70

#define NV50_3D_GP_ADDRESS_LOW					0x00000f74

#define NV50_3D_UNK0F78						0x00000f78

#define NV50_3D_VP_ADDRESS_HIGH					0x00000f7c

#define NV50_3D_VP_ADDRESS_LOW					0x00000f80

#define NV50_3D_VERTEX_RUNOUT_ADDRESS_HIGH			0x00000f84

#define NV50_3D_VERTEX_RUNOUT_ADDRESS_LOW			0x00000f88

#define NV50_3D_UNK0F8C						0x00000f8c

#define NV50_3D_COLOR_MASK_COMMON				0x00000f90

#define NV50_3D_UNK0F94						0x00000f94

#define NV50_3D_UNK0F98						0x00000f98

#define NV50_3D_DEPTH_BOUNDS(i0)			       (0x00000f9c + 0x4*(i0))
#define NV50_3D_DEPTH_BOUNDS__ESIZE				0x00000004
#define NV50_3D_DEPTH_BOUNDS__LEN				0x00000002

#define NV50_3D_FP_ADDRESS_HIGH					0x00000fa4

#define NV50_3D_FP_ADDRESS_LOW					0x00000fa8

#define NV50_3D_UNK0FAC						0x00000fac
#define NV50_3D_UNK0FAC_UNK0					0x00000001
#define NVA0_3D_UNK0FAC_UNK2					0x00000002
#define NV50_3D_UNK0FAC_UNK1__MASK				0x000ffff0
#define NV50_3D_UNK0FAC_UNK1__SHIFT				4

#define NV50_3D_UNK0FB0						0x00000fb0

#define NV50_3D_UNK0FB4						0x00000fb4

#define NV50_3D_UNK0FB8						0x00000fb8

#define NV50_3D_MSAA_MASK(i0)				       (0x00000fbc + 0x4*(i0))
#define NV50_3D_MSAA_MASK__ESIZE				0x00000004
#define NV50_3D_MSAA_MASK__LEN					0x00000004

#define NV50_3D_CLIPID_ADDRESS_HIGH				0x00000fcc

#define NV50_3D_CLIPID_ADDRESS_LOW				0x00000fd0

#define NV50_3D_SEMANTIC_VIEWPORT				0x00000fd4
#define NV50_3D_SEMANTIC_VIEWPORT_VIEWPORT_ID__MASK		0x000000ff
#define NV50_3D_SEMANTIC_VIEWPORT_VIEWPORT_ID__SHIFT		0

#define NV50_3D_UNK0FD8						0x00000fd8
#define NV50_3D_UNK0FD8_UNK0					0x00000001
#define NV50_3D_UNK0FD8_UNK1					0x00000010

#define NV50_3D_UNK0FDC						0x00000fdc

#define NV50_3D_ZETA_ADDRESS_HIGH				0x00000fe0

#define NV50_3D_ZETA_ADDRESS_LOW				0x00000fe4

#define NV50_3D_ZETA_FORMAT					0x00000fe8

#define NV50_3D_ZETA_TILE_MODE					0x00000fec

#define NV50_3D_ZETA_LAYER_STRIDE				0x00000ff0
#define NV50_3D_ZETA_LAYER_STRIDE__SHR				2

#define NV50_3D_SCREEN_SCISSOR_HORIZ				0x00000ff4
#define NV50_3D_SCREEN_SCISSOR_HORIZ_W__MASK			0xffff0000
#define NV50_3D_SCREEN_SCISSOR_HORIZ_W__SHIFT			16
#define NV50_3D_SCREEN_SCISSOR_HORIZ_X__MASK			0x0000ffff
#define NV50_3D_SCREEN_SCISSOR_HORIZ_X__SHIFT			0

#define NV50_3D_SCREEN_SCISSOR_VERT				0x00000ff8
#define NV50_3D_SCREEN_SCISSOR_VERT_H__MASK			0xffff0000
#define NV50_3D_SCREEN_SCISSOR_VERT_H__SHIFT			16
#define NV50_3D_SCREEN_SCISSOR_VERT_Y__MASK			0x0000ffff
#define NV50_3D_SCREEN_SCISSOR_VERT_Y__SHIFT			0

#define NV50_3D_UNK0FFC						0x00000ffc

#define NV50_3D_VERTEX_ARRAY_PER_INSTANCE(i0)		       (0x00001000 + 0x4*(i0))
#define NV50_3D_VERTEX_ARRAY_PER_INSTANCE__ESIZE		0x00000004
#define NV50_3D_VERTEX_ARRAY_PER_INSTANCE__LEN			0x00000010

#define NV50_3D_UNK1040(i0)				       (0x00001040 + 0x4*(i0))
#define NV50_3D_UNK1040__ESIZE					0x00000004
#define NV50_3D_UNK1040__LEN					0x00000010

#define NV50_3D_VERTEX_ARRAY_LIMIT_HIGH(i0)		       (0x00001080 + 0x8*(i0))
#define NV50_3D_VERTEX_ARRAY_LIMIT_HIGH__ESIZE			0x00000008
#define NV50_3D_VERTEX_ARRAY_LIMIT_HIGH__LEN			0x00000010

#define NV50_3D_VERTEX_ARRAY_LIMIT_LOW(i0)		       (0x00001084 + 0x8*(i0))
#define NV50_3D_VERTEX_ARRAY_LIMIT_LOW__ESIZE			0x00000008
#define NV50_3D_VERTEX_ARRAY_LIMIT_LOW__LEN			0x00000010

#define NV50_3D_UNK1100						0x00001100

#define NV84_3D_UNK1104						0x00001104
#define NV84_3D_UNK1104_0__MASK					0x0000ffff
#define NV84_3D_UNK1104_0__SHIFT				0
#define NV84_3D_UNK1104_0__MAX					0x00002000
#define NV84_3D_UNK1104_0__ALIGN				0x00000040
#define NV84_3D_UNK1104_1__MASK					0xffff0000
#define NV84_3D_UNK1104_1__SHIFT				16
#define NV84_3D_UNK1104_1__MAX					0x00002000
#define NV84_3D_UNK1104_1__ALIGN				0x00000040

#define NV84_3D_UNK1108						0x00001108
#define NV84_3D_UNK1108_0					0x00000001
#define NV84_3D_UNK1108_1					0x00000010

#define NV84_3D_UNK110C						0x0000110c

#define NV84_3D_UNK1110						0x00001110

#define NV84_3D_WRCACHE_FLUSH					0x00001114

#define NV84_3D_VERTEX_ID_BASE					0x00001118

#define NV84_3D_PRIMITIVE_ID					0x0000111c

#define NVA3_3D_VTX_ATTR_MASK_UNK0DD0_ALT(i0)		       (0x00001120 + 0x4*(i0))
#define NVA3_3D_VTX_ATTR_MASK_UNK0DD0_ALT__ESIZE		0x00000004
#define NVA3_3D_VTX_ATTR_MASK_UNK0DD0_ALT__LEN			0x00000004

#define NVA3_3D_VP_ATTR_EN_ALT(i0)			       (0x00001130 + 0x4*(i0))
#define NVA3_3D_VP_ATTR_EN_ALT__ESIZE				0x00000004
#define NVA3_3D_VP_ATTR_EN_ALT__LEN				0x00000004
#define NVA3_3D_VP_ATTR_EN_ALT_7__MASK				0xf0000000
#define NVA3_3D_VP_ATTR_EN_ALT_7__SHIFT				28
#define NVA3_3D_VP_ATTR_EN_ALT_7_X				0x10000000
#define NVA3_3D_VP_ATTR_EN_ALT_7_Y				0x20000000
#define NVA3_3D_VP_ATTR_EN_ALT_7_Z				0x40000000
#define NVA3_3D_VP_ATTR_EN_ALT_7_W				0x80000000
#define NVA3_3D_VP_ATTR_EN_ALT_6__MASK				0x0f000000
#define NVA3_3D_VP_ATTR_EN_ALT_6__SHIFT				24
#define NVA3_3D_VP_ATTR_EN_ALT_6_X				0x01000000
#define NVA3_3D_VP_ATTR_EN_ALT_6_Y				0x02000000
#define NVA3_3D_VP_ATTR_EN_ALT_6_Z				0x04000000
#define NVA3_3D_VP_ATTR_EN_ALT_6_W				0x08000000
#define NVA3_3D_VP_ATTR_EN_ALT_5__MASK				0x00f00000
#define NVA3_3D_VP_ATTR_EN_ALT_5__SHIFT				20
#define NVA3_3D_VP_ATTR_EN_ALT_5_X				0x00100000
#define NVA3_3D_VP_ATTR_EN_ALT_5_Y				0x00200000
#define NVA3_3D_VP_ATTR_EN_ALT_5_Z				0x00400000
#define NVA3_3D_VP_ATTR_EN_ALT_5_W				0x00800000
#define NVA3_3D_VP_ATTR_EN_ALT_4__MASK				0x000f0000
#define NVA3_3D_VP_ATTR_EN_ALT_4__SHIFT				16
#define NVA3_3D_VP_ATTR_EN_ALT_4_X				0x00010000
#define NVA3_3D_VP_ATTR_EN_ALT_4_Y				0x00020000
#define NVA3_3D_VP_ATTR_EN_ALT_4_Z				0x00040000
#define NVA3_3D_VP_ATTR_EN_ALT_4_W				0x00080000
#define NVA3_3D_VP_ATTR_EN_ALT_3__MASK				0x0000f000
#define NVA3_3D_VP_ATTR_EN_ALT_3__SHIFT				12
#define NVA3_3D_VP_ATTR_EN_ALT_3_X				0x00001000
#define NVA3_3D_VP_ATTR_EN_ALT_3_Y				0x00002000
#define NVA3_3D_VP_ATTR_EN_ALT_3_Z				0x00004000
#define NVA3_3D_VP_ATTR_EN_ALT_3_W				0x00008000
#define NVA3_3D_VP_ATTR_EN_ALT_2__MASK				0x00000f00
#define NVA3_3D_VP_ATTR_EN_ALT_2__SHIFT				8
#define NVA3_3D_VP_ATTR_EN_ALT_2_X				0x00000100
#define NVA3_3D_VP_ATTR_EN_ALT_2_Y				0x00000200
#define NVA3_3D_VP_ATTR_EN_ALT_2_Z				0x00000400
#define NVA3_3D_VP_ATTR_EN_ALT_2_W				0x00000800
#define NVA3_3D_VP_ATTR_EN_ALT_1__MASK				0x000000f0
#define NVA3_3D_VP_ATTR_EN_ALT_1__SHIFT				4
#define NVA3_3D_VP_ATTR_EN_ALT_1_X				0x00000010
#define NVA3_3D_VP_ATTR_EN_ALT_1_Y				0x00000020
#define NVA3_3D_VP_ATTR_EN_ALT_1_Z				0x00000040
#define NVA3_3D_VP_ATTR_EN_ALT_1_W				0x00000080
#define NVA3_3D_VP_ATTR_EN_ALT_0__MASK				0x0000000f
#define NVA3_3D_VP_ATTR_EN_ALT_0__SHIFT				0
#define NVA3_3D_VP_ATTR_EN_ALT_0_X				0x00000001
#define NVA3_3D_VP_ATTR_EN_ALT_0_Y				0x00000002
#define NVA3_3D_VP_ATTR_EN_ALT_0_Z				0x00000004
#define NVA3_3D_VP_ATTR_EN_ALT_0_W				0x00000008

#define NVA3_3D_UNK1140						0x00001140

#define NVA0_3D_UNK1144						0x00001144

#define NVA0_3D_VTX_ATTR_DEFINE					0x0000114c
#define NVA0_3D_VTX_ATTR_DEFINE_ATTR__MASK			0x000000ff
#define NVA0_3D_VTX_ATTR_DEFINE_ATTR__SHIFT			0
#define NVA0_3D_VTX_ATTR_DEFINE_COMP__MASK			0x00000700
#define NVA0_3D_VTX_ATTR_DEFINE_COMP__SHIFT			8
#define NVA0_3D_VTX_ATTR_DEFINE_COMP__MIN			0x00000001
#define NVA0_3D_VTX_ATTR_DEFINE_COMP__MAX			0x00000004
#define NVA0_3D_VTX_ATTR_DEFINE_SIZE__MASK			0x00007000
#define NVA0_3D_VTX_ATTR_DEFINE_SIZE__SHIFT			12
#define NVA0_3D_VTX_ATTR_DEFINE_SIZE_8				0x00001000
#define NVA0_3D_VTX_ATTR_DEFINE_SIZE_16				0x00002000
#define NVA0_3D_VTX_ATTR_DEFINE_SIZE_32				0x00004000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE__MASK			0x00070000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE__SHIFT			16
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_SNORM			0x00010000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_UNORM			0x00020000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_SINT			0x00030000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_UINT			0x00040000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_USCALED			0x00050000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_SSCALED			0x00060000
#define NVA0_3D_VTX_ATTR_DEFINE_TYPE_FLOAT			0x00070000

#define NVA0_3D_VTX_ATTR_DATA(i0)			       (0x00001150 + 0x4*(i0))
#define NVA0_3D_VTX_ATTR_DATA__ESIZE				0x00000004
#define NVA0_3D_VTX_ATTR_DATA__LEN				0x00000004

#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT(i0)		       (0x00001160 + 0x4*(i0))
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT__ESIZE			0x00000004
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT__LEN			0x00000020
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_BUFFER__MASK		0x0000001f
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_BUFFER__SHIFT		0
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_CONST			0x00000040
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_OFFSET__MASK		0x001fff80
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_OFFSET__SHIFT		7
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT__MASK		0x07e00000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT__SHIFT		21
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_32_32_32_32	0x00200000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_32_32_32		0x00400000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_16_16_16_16	0x00600000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_32_32		0x00800000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_16_16_16		0x00a00000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_8_8_8_8		0x01400000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_16_16		0x01e00000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_32		0x02400000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_8_8_8		0x02600000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_8_8		0x03000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_16		0x03600000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_8		0x03a00000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_FORMAT_10_10_10_2	0x06000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE__MASK		0x38000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE__SHIFT		27
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_SNORM		0x08000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_UNORM		0x10000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_SINT		0x18000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_UINT		0x20000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_USCALED		0x28000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_SSCALED		0x30000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_TYPE_FLOAT		0x38000000
#define NVA3_3D_VERTEX_ARRAY_ATTRIB_ALT_BGRA			0x80000000

#define NV50_3D_RT_CONTROL					0x0000121c
#define NV50_3D_RT_CONTROL_COUNT__MASK				0x0000000f
#define NV50_3D_RT_CONTROL_COUNT__SHIFT				0
#define NV50_3D_RT_CONTROL_MAP0__MASK				0x00000070
#define NV50_3D_RT_CONTROL_MAP0__SHIFT				4
#define NV50_3D_RT_CONTROL_MAP1__MASK				0x00000380
#define NV50_3D_RT_CONTROL_MAP1__SHIFT				7
#define NV50_3D_RT_CONTROL_MAP2__MASK				0x00001c00
#define NV50_3D_RT_CONTROL_MAP2__SHIFT				10
#define NV50_3D_RT_CONTROL_MAP3__MASK				0x0000e000
#define NV50_3D_RT_CONTROL_MAP3__SHIFT				13
#define NV50_3D_RT_CONTROL_MAP4__MASK				0x00070000
#define NV50_3D_RT_CONTROL_MAP4__SHIFT				16
#define NV50_3D_RT_CONTROL_MAP5__MASK				0x00380000
#define NV50_3D_RT_CONTROL_MAP5__SHIFT				19
#define NV50_3D_RT_CONTROL_MAP6__MASK				0x01c00000
#define NV50_3D_RT_CONTROL_MAP6__SHIFT				22
#define NV50_3D_RT_CONTROL_MAP7__MASK				0x0e000000
#define NV50_3D_RT_CONTROL_MAP7__SHIFT				25

#define NV50_3D_UNK1220						0x00001220

#define NV50_3D_RT_ARRAY_MODE					0x00001224
#define NV50_3D_RT_ARRAY_MODE_LAYERS__MASK			0x0000ffff
#define NV50_3D_RT_ARRAY_MODE_LAYERS__SHIFT			0
#define NV50_3D_RT_ARRAY_MODE_MODE__MASK			0x00010000
#define NV50_3D_RT_ARRAY_MODE_MODE__SHIFT			16
#define NV50_3D_RT_ARRAY_MODE_MODE_2D_ARRAY			0x00000000
#define NV50_3D_RT_ARRAY_MODE_MODE_3D				0x00010000

#define NV50_3D_ZETA_HORIZ					0x00001228

#define NV50_3D_ZETA_VERT					0x0000122c

#define NV50_3D_ZETA_ARRAY_MODE					0x00001230
#define NV50_3D_ZETA_ARRAY_MODE_LAYERS__MASK			0x0000ffff
#define NV50_3D_ZETA_ARRAY_MODE_LAYERS__SHIFT			0
#define NV50_3D_ZETA_ARRAY_MODE_UNK				0x00010000

#define NV50_3D_LINKED_TSC					0x00001234

#define NV50_3D_UNK1238						0x00001238

#define NVA0_3D_DRAW_TFB_BYTES					0x0000123c

#define NV50_3D_RT_HORIZ(i0)				       (0x00001240 + 0x8*(i0))
#define NV50_3D_RT_HORIZ__ESIZE					0x00000008
#define NV50_3D_RT_HORIZ__LEN					0x00000008
#define NV50_3D_RT_HORIZ_WIDTH__MASK				0x0fffffff
#define NV50_3D_RT_HORIZ_WIDTH__SHIFT				0
#define NV50_3D_RT_HORIZ_LINEAR					0x80000000

#define NV50_3D_RT_VERT(i0)				       (0x00001244 + 0x8*(i0))
#define NV50_3D_RT_VERT__ESIZE					0x00000008
#define NV50_3D_RT_VERT__LEN					0x00000008

#define NV50_3D_CB_DEF_ADDRESS_HIGH				0x00001280

#define NV50_3D_CB_DEF_ADDRESS_LOW				0x00001284

#define NV50_3D_CB_DEF_SET					0x00001288
#define NV50_3D_CB_DEF_SET_SIZE__MASK				0x0000ffff
#define NV50_3D_CB_DEF_SET_SIZE__SHIFT				0
#define NV50_3D_CB_DEF_SET_BUFFER__MASK				0x007f0000
#define NV50_3D_CB_DEF_SET_BUFFER__SHIFT			16

#define NV50_3D_UNK128C						0x0000128c
#define NV50_3D_UNK128C_0__MASK					0x00000003
#define NV50_3D_UNK128C_0__SHIFT				0
#define NV50_3D_UNK128C_1__MASK					0x00000030
#define NV50_3D_UNK128C_1__SHIFT				4
#define NV50_3D_UNK128C_2__MASK					0x00000300
#define NV50_3D_UNK128C_2__SHIFT				8
#define NV50_3D_UNK128C_3__MASK					0x00003000
#define NV50_3D_UNK128C_3__SHIFT				12

#define NV50_3D_CALL_LIMIT_LOG					0x00001290
#define NV50_3D_CALL_LIMIT_LOG_VP__MASK				0x0000000f
#define NV50_3D_CALL_LIMIT_LOG_VP__SHIFT			0
#define NV50_3D_CALL_LIMIT_LOG_GP__MASK				0x000000f0
#define NV50_3D_CALL_LIMIT_LOG_GP__SHIFT			4
#define NV50_3D_CALL_LIMIT_LOG_FP__MASK				0x00000f00
#define NV50_3D_CALL_LIMIT_LOG_FP__SHIFT			8

#define NV50_3D_STRMOUT_BUFFERS_CTRL				0x00001294
#define NV50_3D_STRMOUT_BUFFERS_CTRL_INTERLEAVED		0x00000001
#define NVA0_3D_STRMOUT_BUFFERS_CTRL_LIMIT_MODE__MASK		0x00000002
#define NVA0_3D_STRMOUT_BUFFERS_CTRL_LIMIT_MODE__SHIFT		1
#define NVA0_3D_STRMOUT_BUFFERS_CTRL_LIMIT_MODE_PRIMITIVES	0x00000000
#define NVA0_3D_STRMOUT_BUFFERS_CTRL_LIMIT_MODE_OFFSET		0x00000002
#define NV50_3D_STRMOUT_BUFFERS_CTRL_SEPARATE__MASK		0x000000f0
#define NV50_3D_STRMOUT_BUFFERS_CTRL_SEPARATE__SHIFT		4
#define NV50_3D_STRMOUT_BUFFERS_CTRL_STRIDE__MASK		0x000fff00
#define NV50_3D_STRMOUT_BUFFERS_CTRL_STRIDE__SHIFT		8
#define NV50_3D_STRMOUT_BUFFERS_CTRL_STRIDE__MAX		0x00000800

#define NV50_3D_FP_RESULT_COUNT					0x00001298

#define NV50_3D_VTX_UNK129C					0x0000129c

#define NV50_3D_UNK12A0						0x000012a0

#define NV50_3D_UNK12A8						0x000012a8
#define NV50_3D_UNK12A8_UNK1					0x00000001
#define NV50_3D_UNK12A8_UNK2__MASK				0x000ffff0
#define NV50_3D_UNK12A8_UNK2__SHIFT				4

#define NV50_3D_UNK12AC						0x000012ac

#define NV50_3D_UNK12B0						0x000012b0
#define NV50_3D_UNK12B0_UNK0__MASK				0x000000ff
#define NV50_3D_UNK12B0_UNK0__SHIFT				0
#define NV50_3D_UNK12B0_UNK1__MASK				0x0000ff00
#define NV50_3D_UNK12B0_UNK1__SHIFT				8
#define NV50_3D_UNK12B0_UNK2__MASK				0x00ff0000
#define NV50_3D_UNK12B0_UNK2__SHIFT				16
#define NV50_3D_UNK12B0_UNK3__MASK				0xff000000
#define NV50_3D_UNK12B0_UNK3__SHIFT				24
#define NV50_3D_UNK12B0_UNK3__MAX				0x00000080

#define NV50_3D_UNK12B4						0x000012b4

#define NV50_3D_UNK12B8						0x000012b8

#define NV50_3D_DEPTH_TEST_ENABLE				0x000012cc

#define NV50_3D_D3D_FILL_MODE					0x000012d0
#define NV50_3D_D3D_FILL_MODE_POINT				0x00000001
#define NV50_3D_D3D_FILL_MODE_WIREFRAME				0x00000002
#define NV50_3D_D3D_FILL_MODE_SOLID				0x00000003

#define NV50_3D_SHADE_MODEL					0x000012d4
#define NV50_3D_SHADE_MODEL_FLAT				0x00001d00
#define NV50_3D_SHADE_MODEL_SMOOTH				0x00001d01

#define NV50_3D_LOCAL_ADDRESS_HIGH				0x000012d8

#define NV50_3D_LOCAL_ADDRESS_LOW				0x000012dc

#define NV50_3D_LOCAL_SIZE_LOG					0x000012e0

#define NV50_3D_BLEND_INDEPENDENT				0x000012e4

#define NV50_3D_DEPTH_WRITE_ENABLE				0x000012e8

#define NV50_3D_ALPHA_TEST_ENABLE				0x000012ec

#define NV50_3D_PM_SET(i0)				       (0x000012f0 + 0x4*(i0))
#define NV50_3D_PM_SET__ESIZE					0x00000004
#define NV50_3D_PM_SET__LEN					0x00000004

#define NV50_3D_VB_ELEMENT_U8_SETUP				0x00001300
#define NV50_3D_VB_ELEMENT_U8_SETUP_OFFSET__MASK		0xc0000000
#define NV50_3D_VB_ELEMENT_U8_SETUP_OFFSET__SHIFT		30
#define NV50_3D_VB_ELEMENT_U8_SETUP_COUNT__MASK			0x3fffffff
#define NV50_3D_VB_ELEMENT_U8_SETUP_COUNT__SHIFT		0

#define NV50_3D_VB_ELEMENT_U8					0x00001304
#define NV50_3D_VB_ELEMENT_U8_I0__MASK				0x000000ff
#define NV50_3D_VB_ELEMENT_U8_I0__SHIFT				0
#define NV50_3D_VB_ELEMENT_U8_I1__MASK				0x0000ff00
#define NV50_3D_VB_ELEMENT_U8_I1__SHIFT				8
#define NV50_3D_VB_ELEMENT_U8_I2__MASK				0x00ff0000
#define NV50_3D_VB_ELEMENT_U8_I2__SHIFT				16
#define NV50_3D_VB_ELEMENT_U8_I3__MASK				0xff000000
#define NV50_3D_VB_ELEMENT_U8_I3__SHIFT				24

#define NV50_3D_D3D_CULL_MODE					0x00001308
#define NV50_3D_D3D_CULL_MODE_NONE				0x00000001
#define NV50_3D_D3D_CULL_MODE_FRONT				0x00000002
#define NV50_3D_D3D_CULL_MODE_BACK				0x00000003

#define NV50_3D_DEPTH_TEST_FUNC					0x0000130c
#define NV50_3D_DEPTH_TEST_FUNC_NEVER				0x00000200
#define NV50_3D_DEPTH_TEST_FUNC_LESS				0x00000201
#define NV50_3D_DEPTH_TEST_FUNC_EQUAL				0x00000202
#define NV50_3D_DEPTH_TEST_FUNC_LEQUAL				0x00000203
#define NV50_3D_DEPTH_TEST_FUNC_GREATER				0x00000204
#define NV50_3D_DEPTH_TEST_FUNC_NOTEQUAL			0x00000205
#define NV50_3D_DEPTH_TEST_FUNC_GEQUAL				0x00000206
#define NV50_3D_DEPTH_TEST_FUNC_ALWAYS				0x00000207

#define NV50_3D_ALPHA_TEST_REF					0x00001310

#define NV50_3D_ALPHA_TEST_FUNC					0x00001314
#define NV50_3D_ALPHA_TEST_FUNC_NEVER				0x00000200
#define NV50_3D_ALPHA_TEST_FUNC_LESS				0x00000201
#define NV50_3D_ALPHA_TEST_FUNC_EQUAL				0x00000202
#define NV50_3D_ALPHA_TEST_FUNC_LEQUAL				0x00000203
#define NV50_3D_ALPHA_TEST_FUNC_GREATER				0x00000204
#define NV50_3D_ALPHA_TEST_FUNC_NOTEQUAL			0x00000205
#define NV50_3D_ALPHA_TEST_FUNC_GEQUAL				0x00000206
#define NV50_3D_ALPHA_TEST_FUNC_ALWAYS				0x00000207

#define NVA0_3D_DRAW_TFB_STRIDE					0x00001318
#define NVA0_3D_DRAW_TFB_STRIDE__MIN				0x00000001
#define NVA0_3D_DRAW_TFB_STRIDE__MAX				0x00000fff

#define NV50_3D_BLEND_COLOR(i0)				       (0x0000131c + 0x4*(i0))
#define NV50_3D_BLEND_COLOR__ESIZE				0x00000004
#define NV50_3D_BLEND_COLOR__LEN				0x00000004

#define NV50_3D_UNK132C						0x0000132c

#define NV50_3D_TSC_FLUSH					0x00001330
#define NV50_3D_TSC_FLUSH_SPECIFIC				0x00000001
#define NV50_3D_TSC_FLUSH_ENTRY__MASK				0x03fffff0
#define NV50_3D_TSC_FLUSH_ENTRY__SHIFT				4

#define NV50_3D_TIC_FLUSH					0x00001334
#define NV50_3D_TIC_FLUSH_SPECIFIC				0x00000001
#define NV50_3D_TIC_FLUSH_ENTRY__MASK				0x03fffff0
#define NV50_3D_TIC_FLUSH_ENTRY__SHIFT				4

#define NV50_3D_TEX_CACHE_CTL					0x00001338
#define NV50_3D_TEX_CACHE_CTL_UNK1__MASK			0x00000030
#define NV50_3D_TEX_CACHE_CTL_UNK1__SHIFT			4

#define NV50_3D_BLEND_SEPARATE_ALPHA				0x0000133c

#define NV50_3D_BLEND_EQUATION_RGB				0x00001340
#define NV50_3D_BLEND_EQUATION_RGB_FUNC_ADD			0x00008006
#define NV50_3D_BLEND_EQUATION_RGB_MIN				0x00008007
#define NV50_3D_BLEND_EQUATION_RGB_MAX				0x00008008
#define NV50_3D_BLEND_EQUATION_RGB_FUNC_SUBTRACT		0x0000800a
#define NV50_3D_BLEND_EQUATION_RGB_FUNC_REVERSE_SUBTRACT	0x0000800b

#define NV50_3D_BLEND_FUNC_SRC_RGB				0x00001344

#define NV50_3D_BLEND_FUNC_DST_RGB				0x00001348

#define NV50_3D_BLEND_EQUATION_ALPHA				0x0000134c
#define NV50_3D_BLEND_EQUATION_ALPHA_FUNC_ADD			0x00008006
#define NV50_3D_BLEND_EQUATION_ALPHA_MIN			0x00008007
#define NV50_3D_BLEND_EQUATION_ALPHA_MAX			0x00008008
#define NV50_3D_BLEND_EQUATION_ALPHA_FUNC_SUBTRACT		0x0000800a
#define NV50_3D_BLEND_EQUATION_ALPHA_FUNC_REVERSE_SUBTRACT	0x0000800b

#define NV50_3D_BLEND_FUNC_SRC_ALPHA				0x00001350

#define NV50_3D_UNK1354						0x00001354

#define NV50_3D_BLEND_FUNC_DST_ALPHA				0x00001358

#define NV50_3D_BLEND_ENABLE_COMMON				0x0000135c

#define NV50_3D_BLEND_ENABLE(i0)			       (0x00001360 + 0x4*(i0))
#define NV50_3D_BLEND_ENABLE__ESIZE				0x00000004
#define NV50_3D_BLEND_ENABLE__LEN				0x00000008

#define NV50_3D_STENCIL_ENABLE					0x00001380

#define NV50_3D_STENCIL_FRONT_OP_FAIL				0x00001384
#define NV50_3D_STENCIL_FRONT_OP_FAIL_ZERO			0x00000000
#define NV50_3D_STENCIL_FRONT_OP_FAIL_INVERT			0x0000150a
#define NV50_3D_STENCIL_FRONT_OP_FAIL_KEEP			0x00001e00
#define NV50_3D_STENCIL_FRONT_OP_FAIL_REPLACE			0x00001e01
#define NV50_3D_STENCIL_FRONT_OP_FAIL_INCR			0x00001e02
#define NV50_3D_STENCIL_FRONT_OP_FAIL_DECR			0x00001e03
#define NV50_3D_STENCIL_FRONT_OP_FAIL_INCR_WRAP			0x00008507
#define NV50_3D_STENCIL_FRONT_OP_FAIL_DECR_WRAP			0x00008508

#define NV50_3D_STENCIL_FRONT_OP_ZFAIL				0x00001388
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_ZERO			0x00000000
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_INVERT			0x0000150a
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_KEEP			0x00001e00
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_REPLACE			0x00001e01
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_INCR			0x00001e02
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_DECR			0x00001e03
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_INCR_WRAP		0x00008507
#define NV50_3D_STENCIL_FRONT_OP_ZFAIL_DECR_WRAP		0x00008508

#define NV50_3D_STENCIL_FRONT_OP_ZPASS				0x0000138c
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_ZERO			0x00000000
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_INVERT			0x0000150a
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_KEEP			0x00001e00
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_REPLACE			0x00001e01
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_INCR			0x00001e02
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_DECR			0x00001e03
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_INCR_WRAP		0x00008507
#define NV50_3D_STENCIL_FRONT_OP_ZPASS_DECR_WRAP		0x00008508

#define NV50_3D_STENCIL_FRONT_FUNC_FUNC				0x00001390
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_NEVER			0x00000200
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_LESS			0x00000201
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_EQUAL			0x00000202
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_LEQUAL			0x00000203
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_GREATER			0x00000204
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_NOTEQUAL		0x00000205
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_GEQUAL			0x00000206
#define NV50_3D_STENCIL_FRONT_FUNC_FUNC_ALWAYS			0x00000207

#define NV50_3D_STENCIL_FRONT_FUNC_REF				0x00001394

#define NV50_3D_STENCIL_FRONT_MASK				0x00001398

#define NV50_3D_STENCIL_FRONT_FUNC_MASK				0x0000139c

#define NV50_3D_UNK13A0						0x000013a0

#define NVA0_3D_DRAW_TFB_BASE					0x000013a4

#define NV50_3D_FRAG_COLOR_CLAMP_EN				0x000013a8
#define NV50_3D_FRAG_COLOR_CLAMP_EN_0				0x00000001
#define NV50_3D_FRAG_COLOR_CLAMP_EN_1				0x00000010
#define NV50_3D_FRAG_COLOR_CLAMP_EN_2				0x00000100
#define NV50_3D_FRAG_COLOR_CLAMP_EN_3				0x00001000
#define NV50_3D_FRAG_COLOR_CLAMP_EN_4				0x00010000
#define NV50_3D_FRAG_COLOR_CLAMP_EN_5				0x00100000
#define NV50_3D_FRAG_COLOR_CLAMP_EN_6				0x01000000
#define NV50_3D_FRAG_COLOR_CLAMP_EN_7				0x10000000

#define NV50_3D_SCREEN_Y_CONTROL				0x000013ac
#define NV50_3D_SCREEN_Y_CONTROL_Y_NEGATE			0x00000001
#define NV50_3D_SCREEN_Y_CONTROL_TRIANGLE_RAST_FLIP		0x00000010

#define NV50_3D_LINE_WIDTH					0x000013b0

#define NV50_3D_TEX_LIMITS(i0)				       (0x000013b4 + 0x4*(i0))
#define NV50_3D_TEX_LIMITS__ESIZE				0x00000004
#define NV50_3D_TEX_LIMITS__LEN					0x00000003
#define NV50_3D_TEX_LIMITS_SAMPLERS_LOG2__MASK			0x0000000f
#define NV50_3D_TEX_LIMITS_SAMPLERS_LOG2__SHIFT			0
#define NV50_3D_TEX_LIMITS_SAMPLERS_LOG2__MIN			0x00000000
#define NV50_3D_TEX_LIMITS_SAMPLERS_LOG2__MAX			0x00000004
#define NV50_3D_TEX_LIMITS_TEXTURES_LOG2__MASK			0x000000f0
#define NV50_3D_TEX_LIMITS_TEXTURES_LOG2__SHIFT			4
#define NV50_3D_TEX_LIMITS_TEXTURES_LOG2__MIN			0x00000000
#define NV50_3D_TEX_LIMITS_TEXTURES_LOG2__MAX			0x00000007

#define NV50_3D_POINT_COORD_REPLACE_MAP(i0)		       (0x000013c0 + 0x4*(i0))
#define NV50_3D_POINT_COORD_REPLACE_MAP__ESIZE			0x00000004
#define NV50_3D_POINT_COORD_REPLACE_MAP__LEN			0x00000010

#define NV50_3D_UNK1400_LANES					0x00001400

#define NV50_3D_UNK1404						0x00001404

#define NV50_3D_UNK1408						0x00001408

#define NV50_3D_VP_START_ID					0x0000140c

#define NV50_3D_GP_START_ID					0x00001410

#define NV50_3D_FP_START_ID					0x00001414

#define NVA3_3D_UNK1418						0x00001418

#define NV50_3D_UNK141C						0x0000141c

#define NV50_3D_GP_VERTEX_OUTPUT_COUNT				0x00001420
#define NV50_3D_GP_VERTEX_OUTPUT_COUNT__MIN			0x00000001
#define NV50_3D_GP_VERTEX_OUTPUT_COUNT__MAX			0x00000400

#define NV50_3D_VERTEX_ARRAY_FLUSH				0x0000142c

#define NV50_3D_UNK1430						0x00001430
#define NV50_3D_UNK1430_UNK0					0x00000010
#define NV50_3D_UNK1430_UNK1					0x00000100

#define NV50_3D_VB_ELEMENT_BASE					0x00001434

#define NV50_3D_VB_INSTANCE_BASE				0x00001438

#define NV50_3D_CLEAR_FLAGS					0x0000143c
#define NV50_3D_CLEAR_FLAGS_STENCIL_MASK			0x00000001
#define NV50_3D_CLEAR_FLAGS_CLEAR_RECT__MASK			0x00000010
#define NV50_3D_CLEAR_FLAGS_CLEAR_RECT__SHIFT			4
#define NV50_3D_CLEAR_FLAGS_CLEAR_RECT_SCISSOR			0x00000000
#define NV50_3D_CLEAR_FLAGS_CLEAR_RECT_VIEWPORT			0x00000000

#define NV50_3D_CODE_CB_FLUSH					0x00001440

#define NV50_3D_BIND_TSC(i0)				       (0x00001444 + 0x8*(i0))
#define NV50_3D_BIND_TSC__ESIZE					0x00000008
#define NV50_3D_BIND_TSC__LEN					0x00000003
#define NV50_3D_BIND_TSC_VALID					0x00000001
#define NV50_3D_BIND_TSC_SAMPLER__MASK				0x000000f0
#define NV50_3D_BIND_TSC_SAMPLER__SHIFT				4
#define NV50_3D_BIND_TSC_TSC__MASK				0x001ff000
#define NV50_3D_BIND_TSC_TSC__SHIFT				12

#define NV50_3D_BIND_TIC(i0)				       (0x00001448 + 0x8*(i0))
#define NV50_3D_BIND_TIC__ESIZE					0x00000008
#define NV50_3D_BIND_TIC__LEN					0x00000003
#define NV50_3D_BIND_TIC_VALID					0x00000001
#define NV50_3D_BIND_TIC_TEXTURE__MASK				0x000001fe
#define NV50_3D_BIND_TIC_TEXTURE__SHIFT				1
#define NV50_3D_BIND_TIC_TIC__MASK				0x7ffffe00
#define NV50_3D_BIND_TIC_TIC__SHIFT				9

#define NV50_3D_BIND_TSC2(i0)				       (0x00001468 + 0x8*(i0))
#define NV50_3D_BIND_TSC2__ESIZE				0x00000008
#define NV50_3D_BIND_TSC2__LEN					0x00000003
#define NV50_3D_BIND_TSC2_VALID					0x00000001
#define NV50_3D_BIND_TSC2_SAMPLER__MASK				0x00000010
#define NV50_3D_BIND_TSC2_SAMPLER__SHIFT			4
#define NV50_3D_BIND_TSC2_TSC__MASK				0x001ff000
#define NV50_3D_BIND_TSC2_TSC__SHIFT				12

#define NV50_3D_BIND_TIC2(i0)				       (0x0000146c + 0x8*(i0))
#define NV50_3D_BIND_TIC2__ESIZE				0x00000008
#define NV50_3D_BIND_TIC2__LEN					0x00000003
#define NV50_3D_BIND_TIC2_VALID					0x00000001
#define NV50_3D_BIND_TIC2_TEXTURE__MASK				0x00000002
#define NV50_3D_BIND_TIC2_TEXTURE__SHIFT			1
#define NV50_3D_BIND_TIC2_TIC__MASK				0x7ffffe00
#define NV50_3D_BIND_TIC2_TIC__SHIFT				9

#define NV50_3D_STRMOUT_MAP(i0)				       (0x00001480 + 0x4*(i0))
#define NV50_3D_STRMOUT_MAP__ESIZE				0x00000004
#define NV50_3D_STRMOUT_MAP__LEN				0x00000020

#define NV50_3D_CLIPID_HEIGHT					0x00001504
#define NV50_3D_CLIPID_HEIGHT__MAX				0x00002000

#define NV50_3D_CLIPID_FILL_RECT_HORIZ				0x00001508
#define NV50_3D_CLIPID_FILL_RECT_HORIZ_LOW__MASK		0x0000ffff
#define NV50_3D_CLIPID_FILL_RECT_HORIZ_LOW__SHIFT		0
#define NV50_3D_CLIPID_FILL_RECT_HORIZ_HIGH__MASK		0xffff0000
#define NV50_3D_CLIPID_FILL_RECT_HORIZ_HIGH__SHIFT		16

#define NV50_3D_CLIPID_FILL_RECT_VERT				0x0000150c
#define NV50_3D_CLIPID_FILL_RECT_VERT_LOW__MASK			0x0000ffff
#define NV50_3D_CLIPID_FILL_RECT_VERT_LOW__SHIFT		0
#define NV50_3D_CLIPID_FILL_RECT_VERT_HIGH__MASK		0xffff0000
#define NV50_3D_CLIPID_FILL_RECT_VERT_HIGH__SHIFT		16

#define NV50_3D_CLIP_DISTANCE_ENABLE				0x00001510
#define NV50_3D_CLIP_DISTANCE_ENABLE_0				0x00000001
#define NV50_3D_CLIP_DISTANCE_ENABLE_1				0x00000002
#define NV50_3D_CLIP_DISTANCE_ENABLE_2				0x00000004
#define NV50_3D_CLIP_DISTANCE_ENABLE_3				0x00000008
#define NV50_3D_CLIP_DISTANCE_ENABLE_4				0x00000010
#define NV50_3D_CLIP_DISTANCE_ENABLE_5				0x00000020
#define NV50_3D_CLIP_DISTANCE_ENABLE_6				0x00000040
#define NV50_3D_CLIP_DISTANCE_ENABLE_7				0x00000080

#define NV50_3D_SAMPLECNT_ENABLE				0x00001514

#define NV50_3D_POINT_SIZE					0x00001518

#define NV50_3D_ZCULL_STATCTRS_ENABLE				0x0000151c

#define NV50_3D_POINT_SPRITE_ENABLE				0x00001520

#define NVA0_3D_UNK152C						0x0000152c
#define NVA0_3D_UNK152C_UNK0					0x00000001
#define NVA0_3D_UNK152C_UNK1					0x00000010
#define NVA0_3D_UNK152C_UNK2					0x00000100
#define NVA0_3D_UNK152C_UNK3__MASK				0x000ff000
#define NVA0_3D_UNK152C_UNK3__SHIFT				12
#define NVA0_3D_UNK152C_UNK3__MAX				0x00000028

#define NV50_3D_COUNTER_RESET					0x00001530
#define NV50_3D_COUNTER_RESET_SAMPLECNT				0x00000001
#define NV50_3D_COUNTER_RESET_ZCULL_STATS			0x00000002
#define NVA0_3D_COUNTER_RESET_STRMOUT_VERTICES			0x00000008
#define NV50_3D_COUNTER_RESET_TRANSFORM_FEEDBACK		0x00000010
#define NV50_3D_COUNTER_RESET_GENERATED_PRIMITIVES		0x00000011
#define NV50_3D_COUNTER_RESET_VFETCH_VERTICES			0x00000012
#define NV50_3D_COUNTER_RESET_VFETCH_PRIMITIVES			0x00000013
#define NV50_3D_COUNTER_RESET_VP_LAUNCHES			0x00000015
#define NV50_3D_COUNTER_RESET_GP_LAUNCHES			0x0000001a
#define NV50_3D_COUNTER_RESET_GP_PRIMITIVES_OUT			0x0000001b
#define NV50_3D_COUNTER_RESET_RAST_PRIMITIVES_PRECLIP		0x0000001c
#define NV50_3D_COUNTER_RESET_RAST_PRIMITIVES_POSTCLIP		0x0000001d
#define NV50_3D_COUNTER_RESET_FP_PIXELS				0x0000001e

#define NV50_3D_MULTISAMPLE_ENABLE				0x00001534

#define NV50_3D_ZETA_ENABLE					0x00001538

#define NV50_3D_MULTISAMPLE_CTRL				0x0000153c
#define NV50_3D_MULTISAMPLE_CTRL_ALPHA_TO_COVERAGE		0x00000001
#define NV50_3D_MULTISAMPLE_CTRL_ALPHA_TO_ONE			0x00000010

#define NV50_3D_NOPERSPECTIVE_BITMAP(i0)		       (0x00001540 + 0x4*(i0))
#define NV50_3D_NOPERSPECTIVE_BITMAP__ESIZE			0x00000004
#define NV50_3D_NOPERSPECTIVE_BITMAP__LEN			0x00000004

#define NV50_3D_COND_ADDRESS_HIGH				0x00001550

#define NV50_3D_COND_ADDRESS_LOW				0x00001554

#define NV50_3D_COND_MODE					0x00001558
#define NV50_3D_COND_MODE_NEVER					0x00000000
#define NV50_3D_COND_MODE_ALWAYS				0x00000001
#define NV50_3D_COND_MODE_RES_NON_ZERO				0x00000002
#define NV50_3D_COND_MODE_EQUAL					0x00000003
#define NV50_3D_COND_MODE_NOT_EQUAL				0x00000004

#define NV50_3D_TSC_ADDRESS_HIGH				0x0000155c

#define NV50_3D_TSC_ADDRESS_LOW					0x00001560
#define NV50_3D_TSC_ADDRESS_LOW__ALIGN				0x00000020

#define NV50_3D_TSC_LIMIT					0x00001564
#define NV50_3D_TSC_LIMIT__MAX					0x00001fff

#define NV50_3D_UNK1568						0x00001568

#define NV50_3D_POLYGON_OFFSET_FACTOR				0x0000156c

#define NV50_3D_LINE_SMOOTH_ENABLE				0x00001570

#define NV50_3D_TIC_ADDRESS_HIGH				0x00001574

#define NV50_3D_TIC_ADDRESS_LOW					0x00001578

#define NV50_3D_TIC_LIMIT					0x0000157c

#define NV50_3D_PM_CONTROL(i0)				       (0x00001580 + 0x4*(i0))
#define NV50_3D_PM_CONTROL__ESIZE				0x00000004
#define NV50_3D_PM_CONTROL__LEN					0x00000004
#define NV50_3D_PM_CONTROL_UNK0					0x00000001
#define NV50_3D_PM_CONTROL_UNK1__MASK				0x00000070
#define NV50_3D_PM_CONTROL_UNK1__SHIFT				4
#define NV50_3D_PM_CONTROL_UNK2__MASK				0x00ffff00
#define NV50_3D_PM_CONTROL_UNK2__SHIFT				8
#define NV50_3D_PM_CONTROL_UNK3__MASK				0xff000000
#define NV50_3D_PM_CONTROL_UNK3__SHIFT				24

#define NV50_3D_ZCULL_REGION					0x00001590

#define NV50_3D_STENCIL_TWO_SIDE_ENABLE				0x00001594

#define NV50_3D_STENCIL_BACK_OP_FAIL				0x00001598
#define NV50_3D_STENCIL_BACK_OP_FAIL_ZERO			0x00000000
#define NV50_3D_STENCIL_BACK_OP_FAIL_INVERT			0x0000150a
#define NV50_3D_STENCIL_BACK_OP_FAIL_KEEP			0x00001e00
#define NV50_3D_STENCIL_BACK_OP_FAIL_REPLACE			0x00001e01
#define NV50_3D_STENCIL_BACK_OP_FAIL_INCR			0x00001e02
#define NV50_3D_STENCIL_BACK_OP_FAIL_DECR			0x00001e03
#define NV50_3D_STENCIL_BACK_OP_FAIL_INCR_WRAP			0x00008507
#define NV50_3D_STENCIL_BACK_OP_FAIL_DECR_WRAP			0x00008508

#define NV50_3D_STENCIL_BACK_OP_ZFAIL				0x0000159c
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_ZERO			0x00000000
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_INVERT			0x0000150a
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_KEEP			0x00001e00
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_REPLACE			0x00001e01
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_INCR			0x00001e02
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_DECR			0x00001e03
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_INCR_WRAP			0x00008507
#define NV50_3D_STENCIL_BACK_OP_ZFAIL_DECR_WRAP			0x00008508

#define NV50_3D_STENCIL_BACK_OP_ZPASS				0x000015a0
#define NV50_3D_STENCIL_BACK_OP_ZPASS_ZERO			0x00000000
#define NV50_3D_STENCIL_BACK_OP_ZPASS_INVERT			0x0000150a
#define NV50_3D_STENCIL_BACK_OP_ZPASS_KEEP			0x00001e00
#define NV50_3D_STENCIL_BACK_OP_ZPASS_REPLACE			0x00001e01
#define NV50_3D_STENCIL_BACK_OP_ZPASS_INCR			0x00001e02
#define NV50_3D_STENCIL_BACK_OP_ZPASS_DECR			0x00001e03
#define NV50_3D_STENCIL_BACK_OP_ZPASS_INCR_WRAP			0x00008507
#define NV50_3D_STENCIL_BACK_OP_ZPASS_DECR_WRAP			0x00008508

#define NV50_3D_STENCIL_BACK_FUNC_FUNC				0x000015a4
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_NEVER			0x00000200
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_LESS			0x00000201
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_EQUAL			0x00000202
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_LEQUAL			0x00000203
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_GREATER			0x00000204
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_NOTEQUAL			0x00000205
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_GEQUAL			0x00000206
#define NV50_3D_STENCIL_BACK_FUNC_FUNC_ALWAYS			0x00000207

#define NV50_3D_UNK15A8						0x000015a8
#define NV50_3D_UNK15A8_UNK1__MASK				0x00000007
#define NV50_3D_UNK15A8_UNK1__SHIFT				0
#define NV50_3D_UNK15A8_UNK2__MASK				0x00000070
#define NV50_3D_UNK15A8_UNK2__SHIFT				4

#define NV50_3D_UNK15AC						0x000015ac

#define NV50_3D_UNK15B0						0x000015b0
#define NV50_3D_UNK15B0_0					0x00000001
#define NV50_3D_UNK15B0_1					0x00000010
#define NV50_3D_UNK15B0_2					0x00000100

#define NV50_3D_CSAA_ENABLE					0x000015b4

#define NV50_3D_FRAMEBUFFER_SRGB				0x000015b8

#define NV50_3D_POLYGON_OFFSET_UNITS				0x000015bc

#define NVA3_3D_UNK15C4						0x000015c4

#define NVA3_3D_UNK15C8						0x000015c8

#define NV50_3D_LAYER						0x000015cc
#define NV50_3D_LAYER_IDX__MASK					0x0000ffff
#define NV50_3D_LAYER_IDX__SHIFT				0
#define NV50_3D_LAYER_USE_GP					0x00010000

#define NV50_3D_MULTISAMPLE_MODE				0x000015d0
#define NV50_3D_MULTISAMPLE_MODE_MS1				0x00000000
#define NV50_3D_MULTISAMPLE_MODE_MS2				0x00000001
#define NV50_3D_MULTISAMPLE_MODE_MS4				0x00000002
#define NV50_3D_MULTISAMPLE_MODE_MS8				0x00000003
#define NV50_3D_MULTISAMPLE_MODE_MS8_ALT			0x00000004
#define NV50_3D_MULTISAMPLE_MODE_MS2_ALT			0x00000005
#define NV50_3D_MULTISAMPLE_MODE_UNK6				0x00000006
#define NV50_3D_MULTISAMPLE_MODE_MS4_CS4			0x00000008
#define NV50_3D_MULTISAMPLE_MODE_MS4_CS12			0x00000009
#define NV50_3D_MULTISAMPLE_MODE_MS8_CS8			0x0000000a
#define NV50_3D_MULTISAMPLE_MODE_MS8_CS24			0x0000000b

#define NV50_3D_VERTEX_BEGIN_D3D				0x000015d4
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE__MASK		0x0fffffff
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE__SHIFT		0
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_POINTS		0x00000001
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_LINES		0x00000002
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_LINE_STRIP		0x00000003
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_TRIANGLES		0x00000004
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_TRIANGLE_STRIP	0x00000005
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_LINES_ADJACENCY	0x0000000a
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_LINE_STRIP_ADJACENCY	0x0000000b
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_TRIANGLES_ADJACENCY	0x0000000c
#define NV50_3D_VERTEX_BEGIN_D3D_PRIMITIVE_TRIANGLE_STRIP_ADJACENCY	0x0000000d
#define NV50_3D_VERTEX_BEGIN_D3D_INSTANCE_NEXT			0x10000000
#define NV84_3D_VERTEX_BEGIN_D3D_PRIMITIVE_ID_CONT		0x20000000
#define NVA0_3D_VERTEX_BEGIN_D3D_INSTANCE_CONT			0x40000000

#define NV50_3D_VERTEX_END_D3D					0x000015d8
#define NV50_3D_VERTEX_END_D3D_UNK0				0x00000001
#define NVA0_3D_VERTEX_END_D3D_UNK1				0x00000002

#define NV50_3D_VERTEX_BEGIN_GL					0x000015dc
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE__MASK			0x0fffffff
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE__SHIFT		0
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_POINTS		0x00000000
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_LINES			0x00000001
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_LINE_LOOP		0x00000002
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_LINE_STRIP		0x00000003
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_TRIANGLES		0x00000004
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_TRIANGLE_STRIP	0x00000005
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_TRIANGLE_FAN		0x00000006
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_QUADS			0x00000007
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_QUAD_STRIP		0x00000008
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_POLYGON		0x00000009
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_LINES_ADJACENCY	0x0000000a
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_LINE_STRIP_ADJACENCY	0x0000000b
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_TRIANGLES_ADJACENCY	0x0000000c
#define NV50_3D_VERTEX_BEGIN_GL_PRIMITIVE_TRIANGLE_STRIP_ADJACENCY	0x0000000d
#define NV50_3D_VERTEX_BEGIN_GL_INSTANCE_NEXT			0x10000000
#define NV84_3D_VERTEX_BEGIN_GL_PRIMITIVE_ID_CONT		0x20000000
#define NVA0_3D_VERTEX_BEGIN_GL_INSTANCE_CONT			0x40000000

#define NV50_3D_VERTEX_END_GL					0x000015e0
#define NV50_3D_VERTEX_END_GL_UNK0				0x00000001
#define NVA0_3D_VERTEX_END_GL_UNK1				0x00000002

#define NV50_3D_EDGEFLAG_ENABLE					0x000015e4

#define NV50_3D_VB_ELEMENT_U32					0x000015e8

#define NV50_3D_VB_ELEMENT_U16_SETUP				0x000015ec
#define NV50_3D_VB_ELEMENT_U16_SETUP_OFFSET__MASK		0xc0000000
#define NV50_3D_VB_ELEMENT_U16_SETUP_OFFSET__SHIFT		30
#define NV50_3D_VB_ELEMENT_U16_SETUP_COUNT__MASK		0x3fffffff
#define NV50_3D_VB_ELEMENT_U16_SETUP_COUNT__SHIFT		0

#define NV50_3D_VB_ELEMENT_U16					0x000015f0
#define NV50_3D_VB_ELEMENT_U16_I0__MASK				0x0000ffff
#define NV50_3D_VB_ELEMENT_U16_I0__SHIFT			0
#define NV50_3D_VB_ELEMENT_U16_I1__MASK				0xffff0000
#define NV50_3D_VB_ELEMENT_U16_I1__SHIFT			16

#define NV50_3D_VERTEX_BASE_HIGH				0x000015f4

#define NV50_3D_VERTEX_BASE_LOW					0x000015f8

#define NV50_3D_VERTEX_DATA					0x00001640

#define NV50_3D_PRIM_RESTART_ENABLE				0x00001644

#define NV50_3D_PRIM_RESTART_INDEX				0x00001648

#define NV50_3D_VP_GP_BUILTIN_ATTR_EN				0x0000164c
#define NV50_3D_VP_GP_BUILTIN_ATTR_EN_VERTEX_ID			0x00000001
#define NV50_3D_VP_GP_BUILTIN_ATTR_EN_INSTANCE_ID		0x00000010
#define NV50_3D_VP_GP_BUILTIN_ATTR_EN_PRIMITIVE_ID		0x00000100
#define NV50_3D_VP_GP_BUILTIN_ATTR_EN_UNK12			0x00001000

#define NV50_3D_VP_ATTR_EN(i0)				       (0x00001650 + 0x4*(i0))
#define NV50_3D_VP_ATTR_EN__ESIZE				0x00000004
#define NV50_3D_VP_ATTR_EN__LEN					0x00000002
#define NV50_3D_VP_ATTR_EN_7__MASK				0xf0000000
#define NV50_3D_VP_ATTR_EN_7__SHIFT				28
#define NV50_3D_VP_ATTR_EN_7_X					0x10000000
#define NV50_3D_VP_ATTR_EN_7_Y					0x20000000
#define NV50_3D_VP_ATTR_EN_7_Z					0x40000000
#define NV50_3D_VP_ATTR_EN_7_W					0x80000000
#define NV50_3D_VP_ATTR_EN_6__MASK				0x0f000000
#define NV50_3D_VP_ATTR_EN_6__SHIFT				24
#define NV50_3D_VP_ATTR_EN_6_X					0x01000000
#define NV50_3D_VP_ATTR_EN_6_Y					0x02000000
#define NV50_3D_VP_ATTR_EN_6_Z					0x04000000
#define NV50_3D_VP_ATTR_EN_6_W					0x08000000
#define NV50_3D_VP_ATTR_EN_5__MASK				0x00f00000
#define NV50_3D_VP_ATTR_EN_5__SHIFT				20
#define NV50_3D_VP_ATTR_EN_5_X					0x00100000
#define NV50_3D_VP_ATTR_EN_5_Y					0x00200000
#define NV50_3D_VP_ATTR_EN_5_Z					0x00400000
#define NV50_3D_VP_ATTR_EN_5_W					0x00800000
#define NV50_3D_VP_ATTR_EN_4__MASK				0x000f0000
#define NV50_3D_VP_ATTR_EN_4__SHIFT				16
#define NV50_3D_VP_ATTR_EN_4_X					0x00010000
#define NV50_3D_VP_ATTR_EN_4_Y					0x00020000
#define NV50_3D_VP_ATTR_EN_4_Z					0x00040000
#define NV50_3D_VP_ATTR_EN_4_W					0x00080000
#define NV50_3D_VP_ATTR_EN_3__MASK				0x0000f000
#define NV50_3D_VP_ATTR_EN_3__SHIFT				12
#define NV50_3D_VP_ATTR_EN_3_X					0x00001000
#define NV50_3D_VP_ATTR_EN_3_Y					0x00002000
#define NV50_3D_VP_ATTR_EN_3_Z					0x00004000
#define NV50_3D_VP_ATTR_EN_3_W					0x00008000
#define NV50_3D_VP_ATTR_EN_2__MASK				0x00000f00
#define NV50_3D_VP_ATTR_EN_2__SHIFT				8
#define NV50_3D_VP_ATTR_EN_2_X					0x00000100
#define NV50_3D_VP_ATTR_EN_2_Y					0x00000200
#define NV50_3D_VP_ATTR_EN_2_Z					0x00000400
#define NV50_3D_VP_ATTR_EN_2_W					0x00000800
#define NV50_3D_VP_ATTR_EN_1__MASK				0x000000f0
#define NV50_3D_VP_ATTR_EN_1__SHIFT				4
#define NV50_3D_VP_ATTR_EN_1_X					0x00000010
#define NV50_3D_VP_ATTR_EN_1_Y					0x00000020
#define NV50_3D_VP_ATTR_EN_1_Z					0x00000040
#define NV50_3D_VP_ATTR_EN_1_W					0x00000080
#define NV50_3D_VP_ATTR_EN_0__MASK				0x0000000f
#define NV50_3D_VP_ATTR_EN_0__SHIFT				0
#define NV50_3D_VP_ATTR_EN_0_X					0x00000001
#define NV50_3D_VP_ATTR_EN_0_Y					0x00000002
#define NV50_3D_VP_ATTR_EN_0_Z					0x00000004
#define NV50_3D_VP_ATTR_EN_0_W					0x00000008

#define NV50_3D_POINT_SMOOTH_ENABLE				0x00001658

#define NV50_3D_POINT_RASTER_RULES				0x0000165c
#define NV50_3D_POINT_RASTER_RULES_OGL				0x00000000
#define NV50_3D_POINT_RASTER_RULES_D3D				0x00000001

#define NV50_3D_POINT_SPRITE_CTRL				0x00001660
#define NV50_3D_POINT_SPRITE_CTRL_COORD_ORIGIN__MASK		0x00000010
#define NV50_3D_POINT_SPRITE_CTRL_COORD_ORIGIN__SHIFT		4
#define NV50_3D_POINT_SPRITE_CTRL_COORD_ORIGIN_LOWER_LEFT	0x00000000
#define NV50_3D_POINT_SPRITE_CTRL_COORD_ORIGIN_UPPER_LEFT	0x00000010

#define NVA0_3D_TEX_MISC					0x00001664
#define NVA0_3D_TEX_MISC_UNK1					0x00000002
#define NVA0_3D_TEX_MISC_SEAMLESS_CUBE_MAP			0x00000004

#define NV50_3D_LINE_SMOOTH_BLUR				0x00001668
#define NV50_3D_LINE_SMOOTH_BLUR_LOW				0x00000000
#define NV50_3D_LINE_SMOOTH_BLUR_MEDIUM				0x00000001
#define NV50_3D_LINE_SMOOTH_BLUR_HIGH				0x00000002

#define NV50_3D_LINE_STIPPLE_ENABLE				0x0000166c

#define NV50_3D_COVERAGE_LUT(i0)			       (0x00001670 + 0x4*(i0))
#define NV50_3D_COVERAGE_LUT__ESIZE				0x00000004
#define NV50_3D_COVERAGE_LUT__LEN				0x00000004
#define NV50_3D_COVERAGE_LUT_0__MASK				0x000000ff
#define NV50_3D_COVERAGE_LUT_0__SHIFT				0
#define NV50_3D_COVERAGE_LUT_1__MASK				0x0000ff00
#define NV50_3D_COVERAGE_LUT_1__SHIFT				8
#define NV50_3D_COVERAGE_LUT_2__MASK				0x00ff0000
#define NV50_3D_COVERAGE_LUT_2__SHIFT				16
#define NV50_3D_COVERAGE_LUT_3__MASK				0xff000000
#define NV50_3D_COVERAGE_LUT_3__SHIFT				24

#define NV50_3D_LINE_STIPPLE					0x00001680
#define NV50_3D_LINE_STIPPLE_FACTOR_M1__MASK			0x000000ff
#define NV50_3D_LINE_STIPPLE_FACTOR_M1__SHIFT			0
#define NV50_3D_LINE_STIPPLE_PATTERN__MASK			0x00ffff00
#define NV50_3D_LINE_STIPPLE_PATTERN__SHIFT			8

#define NV50_3D_PROVOKING_VERTEX_LAST				0x00001684

#define NV50_3D_VERTEX_TWO_SIDE_ENABLE				0x00001688

#define NV50_3D_POLYGON_STIPPLE_ENABLE				0x0000168c

#define NV50_3D_UNK1690						0x00001690
#define NV50_3D_UNK1690_ALWAYS_DERIV				0x00000001
#define NV50_3D_UNK1690_UNK16					0x00010000

#define NV50_3D_SET_PROGRAM_CB					0x00001694
#define NV50_3D_SET_PROGRAM_CB_PROGRAM__MASK			0x000000f0
#define NV50_3D_SET_PROGRAM_CB_PROGRAM__SHIFT			4
#define NV50_3D_SET_PROGRAM_CB_PROGRAM_VERTEX			0x00000000
#define NV50_3D_SET_PROGRAM_CB_PROGRAM_GEOMETRY			0x00000020
#define NV50_3D_SET_PROGRAM_CB_PROGRAM_FRAGMENT			0x00000030
#define NV50_3D_SET_PROGRAM_CB_INDEX__MASK			0x00000f00
#define NV50_3D_SET_PROGRAM_CB_INDEX__SHIFT			8
#define NV50_3D_SET_PROGRAM_CB_BUFFER__MASK			0x0007f000
#define NV50_3D_SET_PROGRAM_CB_BUFFER__SHIFT			12
#define NV50_3D_SET_PROGRAM_CB_VALID				0x00000001

#define NV50_3D_UNK1698						0x00001698
#define NV50_3D_UNK1698_0					0x00000001
#define NV50_3D_UNK1698_1					0x00000010
#define NV50_3D_UNK1698_2					0x00000100

#define NVA3_3D_SAMPLE_SHADING					0x0000169c
#define NVA3_3D_SAMPLE_SHADING_MIN_SAMPLES__MASK		0x0000000f
#define NVA3_3D_SAMPLE_SHADING_MIN_SAMPLES__SHIFT		0
#define NVA3_3D_SAMPLE_SHADING_ENABLE				0x00000010

#define NVA3_3D_UNK16A0						0x000016a0

#define NV50_3D_VP_RESULT_MAP_SIZE				0x000016ac

#define NV50_3D_VP_REG_ALLOC_TEMP				0x000016b0

#define NVA0_3D_UNK16B4						0x000016b4
#define NVA0_3D_UNK16B4_UNK0					0x00000001
#define NVA3_3D_UNK16B4_UNK1					0x00000002

#define NV50_3D_VP_REG_ALLOC_RESULT				0x000016b8

#define NV50_3D_VP_RESULT_MAP(i0)			       (0x000016bc + 0x4*(i0))
#define NV50_3D_VP_RESULT_MAP__ESIZE				0x00000004
#define NV50_3D_VP_RESULT_MAP__LEN				0x00000011
#define NV50_3D_VP_RESULT_MAP_0__MASK				0x000000ff
#define NV50_3D_VP_RESULT_MAP_0__SHIFT				0
#define NV50_3D_VP_RESULT_MAP_1__MASK				0x0000ff00
#define NV50_3D_VP_RESULT_MAP_1__SHIFT				8
#define NV50_3D_VP_RESULT_MAP_2__MASK				0x00ff0000
#define NV50_3D_VP_RESULT_MAP_2__SHIFT				16
#define NV50_3D_VP_RESULT_MAP_3__MASK				0xff000000
#define NV50_3D_VP_RESULT_MAP_3__SHIFT				24

#define NV50_3D_POLYGON_STIPPLE_PATTERN(i0)		       (0x00001700 + 0x4*(i0))
#define NV50_3D_POLYGON_STIPPLE_PATTERN__ESIZE			0x00000004
#define NV50_3D_POLYGON_STIPPLE_PATTERN__LEN			0x00000020

#define NVA0_3D_STRMOUT_OFFSET(i0)			       (0x00001780 + 0x4*(i0))
#define NVA0_3D_STRMOUT_OFFSET__ESIZE				0x00000004
#define NVA0_3D_STRMOUT_OFFSET__LEN				0x00000004

#define NV50_3D_GP_ENABLE					0x00001798

#define NV50_3D_GP_REG_ALLOC_TEMP				0x000017a0

#define NV50_3D_GP_REG_ALLOC_RESULT				0x000017a8

#define NV50_3D_GP_RESULT_MAP_SIZE				0x000017ac

#define NV50_3D_GP_OUTPUT_PRIMITIVE_TYPE			0x000017b0
#define NV50_3D_GP_OUTPUT_PRIMITIVE_TYPE_POINTS			0x00000001
#define NV50_3D_GP_OUTPUT_PRIMITIVE_TYPE_LINE_STRIP		0x00000002
#define NV50_3D_GP_OUTPUT_PRIMITIVE_TYPE_TRIANGLE_STRIP		0x00000003

#define NV50_3D_RASTERIZE_ENABLE				0x000017b4

#define NV50_3D_STRMOUT_ENABLE					0x000017b8

#define NV50_3D_GP_RESULT_MAP(i0)			       (0x000017fc + 0x4*(i0))
#define NV50_3D_GP_RESULT_MAP__ESIZE				0x00000004
#define NV50_3D_GP_RESULT_MAP__LEN				0x00000021
#define NV50_3D_GP_RESULT_MAP_0__MASK				0x000000ff
#define NV50_3D_GP_RESULT_MAP_0__SHIFT				0
#define NV50_3D_GP_RESULT_MAP_1__MASK				0x0000ff00
#define NV50_3D_GP_RESULT_MAP_1__SHIFT				8
#define NV50_3D_GP_RESULT_MAP_2__MASK				0x00ff0000
#define NV50_3D_GP_RESULT_MAP_2__SHIFT				16
#define NV50_3D_GP_RESULT_MAP_3__MASK				0xff000000
#define NV50_3D_GP_RESULT_MAP_3__SHIFT				24

#define NV50_3D_POLYGON_OFFSET_CLAMP				0x0000187c

#define NVA3_3D_VERTEX_ARRAY_PER_INSTANCE_ALT(i0)	       (0x00001880 + 0x4*(i0))
#define NVA3_3D_VERTEX_ARRAY_PER_INSTANCE_ALT__ESIZE		0x00000004
#define NVA3_3D_VERTEX_ARRAY_PER_INSTANCE_ALT__LEN		0x00000020

#define NV50_3D_GP_VIEWPORT_ID_ENABLE				0x00001900

#define NV50_3D_SEMANTIC_COLOR					0x00001904
#define NV50_3D_SEMANTIC_COLOR_FFC0_ID__MASK			0x000000ff
#define NV50_3D_SEMANTIC_COLOR_FFC0_ID__SHIFT			0
#define NV50_3D_SEMANTIC_COLOR_BFC0_ID__MASK			0x0000ff00
#define NV50_3D_SEMANTIC_COLOR_BFC0_ID__SHIFT			8
#define NV50_3D_SEMANTIC_COLOR_COLR_NR__MASK			0x00ff0000
#define NV50_3D_SEMANTIC_COLOR_COLR_NR__SHIFT			16
#define NV50_3D_SEMANTIC_COLOR_CLMP_EN				0x01000000

#define NV50_3D_SEMANTIC_CLIP					0x00001908
#define NV50_3D_SEMANTIC_CLIP_CLIP_START__MASK			0x000000ff
#define NV50_3D_SEMANTIC_CLIP_CLIP_START__SHIFT			0
#define NV50_3D_SEMANTIC_CLIP_CLIP_NUM__MASK			0x00000f00
#define NV50_3D_SEMANTIC_CLIP_CLIP_NUM__SHIFT			8

#define NV50_3D_SEMANTIC_LAYER					0x0000190c
#define NV50_3D_SEMANTIC_LAYER_LAYER_ID__MASK			0x000000ff
#define NV50_3D_SEMANTIC_LAYER_LAYER_ID__SHIFT			0

#define NV50_3D_SEMANTIC_PTSZ					0x00001910
#define NV50_3D_SEMANTIC_PTSZ_PTSZ_EN__MASK			0x00000001
#define NV50_3D_SEMANTIC_PTSZ_PTSZ_EN__SHIFT			0
#define NV50_3D_SEMANTIC_PTSZ_PTSZ_ID__MASK			0x00000ff0
#define NV50_3D_SEMANTIC_PTSZ_PTSZ_ID__SHIFT			4

#define NV50_3D_SEMANTIC_PRIM_ID				0x00001914
#define NV50_3D_SEMANTIC_PRIM_ID_PRIM_ID__MASK			0x000000ff
#define NV50_3D_SEMANTIC_PRIM_ID_PRIM_ID__SHIFT			0

#define NV50_3D_CULL_FACE_ENABLE				0x00001918

#define NV50_3D_FRONT_FACE					0x0000191c
#define NV50_3D_FRONT_FACE_CW					0x00000900
#define NV50_3D_FRONT_FACE_CCW					0x00000901

#define NV50_3D_CULL_FACE					0x00001920
#define NV50_3D_CULL_FACE_FRONT					0x00000404
#define NV50_3D_CULL_FACE_BACK					0x00000405
#define NV50_3D_CULL_FACE_FRONT_AND_BACK			0x00000408

#define NV50_3D_LINE_LAST_PIXEL					0x00001924

#define NVA3_3D_FP_MULTISAMPLE					0x00001928
#define NVA3_3D_FP_MULTISAMPLE_EXPORT_SAMPLE_MASK		0x00000001
#define NVA3_3D_FP_MULTISAMPLE_FORCE_PER_SAMPLE			0x00000002

#define NV50_3D_VIEWPORT_TRANSFORM_EN				0x0000192c

#define NV50_3D_VIEW_VOLUME_CLIP_CTRL				0x0000193c
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK0			0x00000001
#define NVA0_3D_VIEW_VOLUME_CLIP_CTRL_UNK1			0x00000002
#define NVA0_3D_VIEW_VOLUME_CLIP_CTRL_UNK2			0x00000004
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_DEPTH_CLAMP_NEAR		0x00000008
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_DEPTH_CLAMP_FAR		0x00000010
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK7			0x00000080
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK10			0x00000400
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK11			0x00000800
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK12__MASK		0x00003000
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK12__SHIFT		12
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK12_UNK0		0x00000000
#define NV50_3D_VIEW_VOLUME_CLIP_CTRL_UNK12_UNK1		0x00001000
#define NV84_3D_VIEW_VOLUME_CLIP_CTRL_UNK12_UNK2		0x00002000

#define NV50_3D_CLIP_DISTANCE_MODE				0x00001940
#define NV50_3D_CLIP_DISTANCE_MODE_0__MASK			0x00000001
#define NV50_3D_CLIP_DISTANCE_MODE_0__SHIFT			0
#define NV50_3D_CLIP_DISTANCE_MODE_0_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_0_CULL			0x00000001
#define NV50_3D_CLIP_DISTANCE_MODE_1__MASK			0x00000010
#define NV50_3D_CLIP_DISTANCE_MODE_1__SHIFT			4
#define NV50_3D_CLIP_DISTANCE_MODE_1_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_1_CULL			0x00000010
#define NV50_3D_CLIP_DISTANCE_MODE_2__MASK			0x00000100
#define NV50_3D_CLIP_DISTANCE_MODE_2__SHIFT			8
#define NV50_3D_CLIP_DISTANCE_MODE_2_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_2_CULL			0x00000100
#define NV50_3D_CLIP_DISTANCE_MODE_3__MASK			0x00001000
#define NV50_3D_CLIP_DISTANCE_MODE_3__SHIFT			12
#define NV50_3D_CLIP_DISTANCE_MODE_3_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_3_CULL			0x00001000
#define NV50_3D_CLIP_DISTANCE_MODE_4__MASK			0x00010000
#define NV50_3D_CLIP_DISTANCE_MODE_4__SHIFT			16
#define NV50_3D_CLIP_DISTANCE_MODE_4_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_4_CULL			0x00010000
#define NV50_3D_CLIP_DISTANCE_MODE_5__MASK			0x00100000
#define NV50_3D_CLIP_DISTANCE_MODE_5__SHIFT			20
#define NV50_3D_CLIP_DISTANCE_MODE_5_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_5_CULL			0x00100000
#define NV50_3D_CLIP_DISTANCE_MODE_6__MASK			0x01000000
#define NV50_3D_CLIP_DISTANCE_MODE_6__SHIFT			24
#define NV50_3D_CLIP_DISTANCE_MODE_6_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_6_CULL			0x01000000
#define NV50_3D_CLIP_DISTANCE_MODE_7__MASK			0x10000000
#define NV50_3D_CLIP_DISTANCE_MODE_7__SHIFT			28
#define NV50_3D_CLIP_DISTANCE_MODE_7_CLIP			0x00000000
#define NV50_3D_CLIP_DISTANCE_MODE_7_CULL			0x10000000

#define NVA3_3D_UNK1944						0x00001944

#define NV50_3D_CLIP_RECTS_EN					0x0000194c

#define NV50_3D_CLIP_RECTS_MODE					0x00001950
#define NV50_3D_CLIP_RECTS_MODE_INSIDE_ANY			0x00000000
#define NV50_3D_CLIP_RECTS_MODE_OUTSIDE_ALL			0x00000001
#define NV50_3D_CLIP_RECTS_MODE_NEVER				0x00000002

#define NV50_3D_ZCULL_VALIDATE					0x00001954
#define NV50_3D_ZCULL_VALIDATE_CLEAR_UNK0			0x00000001
#define NV50_3D_ZCULL_VALIDATE_CLEAR_UNK1			0x00000010

#define NV50_3D_ZCULL_INVALIDATE				0x00001958

#define NVA3_3D_UNK1960						0x00001960
#define NVA3_3D_UNK1960_0					0x00000001
#define NVA3_3D_UNK1960_1					0x00000010

#define NV50_3D_UNK1968						0x00001968
#define NV50_3D_UNK1968_0					0x00000001
#define NV50_3D_UNK1968_1					0x00000010

#define NV50_3D_FP_CTRL_UNK196C					0x0000196c
#define NV50_3D_FP_CTRL_UNK196C_0				0x00000001
#define NV50_3D_FP_CTRL_UNK196C_1				0x00000010

#define NV50_3D_UNK1978						0x00001978

#define NV50_3D_CLIPID_ENABLE					0x0000197c

#define NV50_3D_CLIPID_WIDTH					0x00001980
#define NV50_3D_CLIPID_WIDTH__MAX				0x00002000
#define NV50_3D_CLIPID_WIDTH__ALIGN				0x00000040

#define NV50_3D_CLIPID_ID					0x00001984

#define NV50_3D_FP_INTERPOLANT_CTRL				0x00001988
#define NV50_3D_FP_INTERPOLANT_CTRL_UMASK__MASK			0xff000000
#define NV50_3D_FP_INTERPOLANT_CTRL_UMASK__SHIFT		24
#define NV50_3D_FP_INTERPOLANT_CTRL_UMASK_X			0x01000000
#define NV50_3D_FP_INTERPOLANT_CTRL_UMASK_Y			0x02000000
#define NV50_3D_FP_INTERPOLANT_CTRL_UMASK_Z			0x04000000
#define NV50_3D_FP_INTERPOLANT_CTRL_UMASK_W			0x08000000
#define NV50_3D_FP_INTERPOLANT_CTRL_COUNT_NONFLAT__MASK		0x00ff0000
#define NV50_3D_FP_INTERPOLANT_CTRL_COUNT_NONFLAT__SHIFT	16
#define NV50_3D_FP_INTERPOLANT_CTRL_OFFSET__MASK		0x0000ff00
#define NV50_3D_FP_INTERPOLANT_CTRL_OFFSET__SHIFT		8
#define NV50_3D_FP_INTERPOLANT_CTRL_COUNT__MASK			0x000000ff
#define NV50_3D_FP_INTERPOLANT_CTRL_COUNT__SHIFT		0

#define NV50_3D_FP_REG_ALLOC_TEMP				0x0000198c

#define NV50_3D_REG_MODE					0x000019a0
#define NV50_3D_REG_MODE_PACKED					0x00000001
#define NV50_3D_REG_MODE_STRIPED				0x00000002

#define NV50_3D_FP_CONTROL					0x000019a8
#define NV50_3D_FP_CONTROL_MULTIPLE_RESULTS			0x00000001
#define NV50_3D_FP_CONTROL_EXPORTS_Z				0x00000100
#define NV50_3D_FP_CONTROL_USES_KIL				0x00100000

#define NV50_3D_DEPTH_BOUNDS_EN					0x000019bc

#define NV50_3D_UNK19C0						0x000019c0

#define NV50_3D_LOGIC_OP_ENABLE					0x000019c4

#define NV50_3D_LOGIC_OP					0x000019c8
#define NV50_3D_LOGIC_OP_CLEAR					0x00001500
#define NV50_3D_LOGIC_OP_AND					0x00001501
#define NV50_3D_LOGIC_OP_AND_REVERSE				0x00001502
#define NV50_3D_LOGIC_OP_COPY					0x00001503
#define NV50_3D_LOGIC_OP_AND_INVERTED				0x00001504
#define NV50_3D_LOGIC_OP_NOOP					0x00001505
#define NV50_3D_LOGIC_OP_XOR					0x00001506
#define NV50_3D_LOGIC_OP_OR					0x00001507
#define NV50_3D_LOGIC_OP_NOR					0x00001508
#define NV50_3D_LOGIC_OP_EQUIV					0x00001509
#define NV50_3D_LOGIC_OP_INVERT					0x0000150a
#define NV50_3D_LOGIC_OP_OR_REVERSE				0x0000150b
#define NV50_3D_LOGIC_OP_COPY_INVERTED				0x0000150c
#define NV50_3D_LOGIC_OP_OR_INVERTED				0x0000150d
#define NV50_3D_LOGIC_OP_NAND					0x0000150e
#define NV50_3D_LOGIC_OP_SET					0x0000150f

#define NV50_3D_ZETA_COMP_ENABLE				0x000019cc

#define NV50_3D_CLEAR_BUFFERS					0x000019d0
#define NV50_3D_CLEAR_BUFFERS_Z					0x00000001
#define NV50_3D_CLEAR_BUFFERS_S					0x00000002
#define NV50_3D_CLEAR_BUFFERS_R					0x00000004
#define NV50_3D_CLEAR_BUFFERS_G					0x00000008
#define NV50_3D_CLEAR_BUFFERS_B					0x00000010
#define NV50_3D_CLEAR_BUFFERS_A					0x00000020
#define NV50_3D_CLEAR_BUFFERS_RT__MASK				0x000003c0
#define NV50_3D_CLEAR_BUFFERS_RT__SHIFT				6
#define NV50_3D_CLEAR_BUFFERS_LAYER__MASK			0x001ffc00
#define NV50_3D_CLEAR_BUFFERS_LAYER__SHIFT			10

#define NV50_3D_CLIPID_FILL					0x000019d4

#define NV50_3D_UNK19D8(i0)				       (0x000019d8 + 0x4*(i0))
#define NV50_3D_UNK19D8__ESIZE					0x00000004
#define NV50_3D_UNK19D8__LEN					0x00000002

#define NV50_3D_RT_COMP_ENABLE(i0)			       (0x000019e0 + 0x4*(i0))
#define NV50_3D_RT_COMP_ENABLE__ESIZE				0x00000004
#define NV50_3D_RT_COMP_ENABLE__LEN				0x00000008

#define NV50_3D_COLOR_MASK(i0)				       (0x00001a00 + 0x4*(i0))
#define NV50_3D_COLOR_MASK__ESIZE				0x00000004
#define NV50_3D_COLOR_MASK__LEN					0x00000008
#define NV50_3D_COLOR_MASK_R					0x0000000f
#define NV50_3D_COLOR_MASK_G					0x000000f0
#define NV50_3D_COLOR_MASK_B					0x00000f00
#define NV50_3D_COLOR_MASK_A					0x0000f000

#define NV50_3D_UNK1A20						0x00001a20

#define NV50_3D_DELAY						0x00001a24

#define NV50_3D_UNK1A28						0x00001a28
#define NV50_3D_UNK1A28_0__MASK					0x000000ff
#define NV50_3D_UNK1A28_0__SHIFT				0
#define NV50_3D_UNK1A28_1					0x00000100

#define NV50_3D_UNK1A2C						0x00001a2c

#define NV50_3D_UNK1A30						0x00001a30

#define NV50_3D_UNK1A34						0x00001a34

#define NV50_3D_UNK1A38						0x00001a38

#define NV50_3D_UNK1A3C						0x00001a3c

#define NV50_3D_UNK1A40(i0)				       (0x00001a40 + 0x4*(i0))
#define NV50_3D_UNK1A40__ESIZE					0x00000004
#define NV50_3D_UNK1A40__LEN					0x00000010
#define NV50_3D_UNK1A40_0__MASK					0x00000007
#define NV50_3D_UNK1A40_0__SHIFT				0
#define NV50_3D_UNK1A40_1__MASK					0x00000070
#define NV50_3D_UNK1A40_1__SHIFT				4
#define NV50_3D_UNK1A40_2__MASK					0x00000700
#define NV50_3D_UNK1A40_2__SHIFT				8
#define NV50_3D_UNK1A40_3__MASK					0x00007000
#define NV50_3D_UNK1A40_3__SHIFT				12
#define NV50_3D_UNK1A40_4__MASK					0x00070000
#define NV50_3D_UNK1A40_4__SHIFT				16
#define NV50_3D_UNK1A40_5__MASK					0x00700000
#define NV50_3D_UNK1A40_5__SHIFT				20
#define NV50_3D_UNK1A40_6__MASK					0x07000000
#define NV50_3D_UNK1A40_6__SHIFT				24
#define NV50_3D_UNK1A40_7__MASK					0x70000000
#define NV50_3D_UNK1A40_7__SHIFT				28

#define NV50_3D_STRMOUT_ADDRESS_HIGH(i0)		       (0x00001a80 + 0x10*(i0))
#define NV50_3D_STRMOUT_ADDRESS_HIGH__ESIZE			0x00000010
#define NV50_3D_STRMOUT_ADDRESS_HIGH__LEN			0x00000004

#define NV50_3D_STRMOUT_ADDRESS_LOW(i0)			       (0x00001a84 + 0x10*(i0))
#define NV50_3D_STRMOUT_ADDRESS_LOW__ESIZE			0x00000010
#define NV50_3D_STRMOUT_ADDRESS_LOW__LEN			0x00000004

#define NV50_3D_STRMOUT_NUM_ATTRIBS(i0)			       (0x00001a88 + 0x10*(i0))
#define NV50_3D_STRMOUT_NUM_ATTRIBS__ESIZE			0x00000010
#define NV50_3D_STRMOUT_NUM_ATTRIBS__LEN			0x00000004
#define NV50_3D_STRMOUT_NUM_ATTRIBS__MAX			0x00000040

#define NVA0_3D_STRMOUT_OFFSET_LIMIT(i0)		       (0x00001a8c + 0x10*(i0))
#define NVA0_3D_STRMOUT_OFFSET_LIMIT__ESIZE			0x00000010
#define NVA0_3D_STRMOUT_OFFSET_LIMIT__LEN			0x00000004

#define NV50_3D_VERTEX_ARRAY_ATTRIB(i0)			       (0x00001ac0 + 0x4*(i0))
#define NV50_3D_VERTEX_ARRAY_ATTRIB__ESIZE			0x00000004
#define NV50_3D_VERTEX_ARRAY_ATTRIB__LEN			0x00000010
#define NV50_3D_VERTEX_ARRAY_ATTRIB_BUFFER__MASK		0x0000000f
#define NV50_3D_VERTEX_ARRAY_ATTRIB_BUFFER__SHIFT		0
#define NV50_3D_VERTEX_ARRAY_ATTRIB_CONST			0x00000010
#define NV50_3D_VERTEX_ARRAY_ATTRIB_OFFSET__MASK		0x0007ffe0
#define NV50_3D_VERTEX_ARRAY_ATTRIB_OFFSET__SHIFT		5
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT__MASK		0x01f80000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT__SHIFT		19
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_32_32_32_32		0x00080000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_32_32_32		0x00100000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_16_16_16_16		0x00180000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_32_32		0x00200000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_16_16_16		0x00280000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_8_8_8_8		0x00500000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_16_16		0x00780000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_32			0x00900000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_8_8_8		0x00980000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_8_8			0x00c00000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_16			0x00d80000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_8			0x00e80000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_FORMAT_10_10_10_2		0x01800000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE__MASK			0x7e000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE__SHIFT			25
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_FLOAT			0x7e000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_UNORM			0x24000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_SNORM			0x12000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_USCALED		0x5a000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_SSCALED		0x6c000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_UINT			0x48000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_TYPE_SINT			0x36000000
#define NV50_3D_VERTEX_ARRAY_ATTRIB_BGRA			0x80000000

#define NV50_3D_QUERY_ADDRESS_HIGH				0x00001b00

#define NV50_3D_QUERY_ADDRESS_LOW				0x00001b04

#define NV50_3D_QUERY_SEQUENCE					0x00001b08

#define NV50_3D_QUERY_GET					0x00001b0c
#define NV50_3D_QUERY_GET_MODE__MASK				0x00000003
#define NV50_3D_QUERY_GET_MODE__SHIFT				0
#define NV50_3D_QUERY_GET_MODE_WRITE_UNK0			0x00000000
#define NV50_3D_QUERY_GET_MODE_SYNC				0x00000001
#define NV50_3D_QUERY_GET_MODE_WRITE_UNK2			0x00000002
#define NV50_3D_QUERY_GET_UNK4					0x00000010
#define NVA0_3D_QUERY_GET_INDEX__MASK				0x000000e0
#define NVA0_3D_QUERY_GET_INDEX__SHIFT				5
#define NV50_3D_QUERY_GET_UNK8					0x00000100
#define NV50_3D_QUERY_GET_UNIT__MASK				0x0000f000
#define NV50_3D_QUERY_GET_UNIT__SHIFT				12
#define NV50_3D_QUERY_GET_UNIT_UNK00				0x00000000
#define NV50_3D_QUERY_GET_UNIT_VFETCH				0x00001000
#define NV50_3D_QUERY_GET_UNIT_VP				0x00002000
#define NV50_3D_QUERY_GET_UNIT_RAST				0x00004000
#define NV50_3D_QUERY_GET_UNIT_STRMOUT				0x00005000
#define NV50_3D_QUERY_GET_UNIT_GP				0x00006000
#define NV50_3D_QUERY_GET_UNIT_ZCULL				0x00007000
#define NV50_3D_QUERY_GET_UNIT_TPROP				0x0000a000
#define NV50_3D_QUERY_GET_UNIT_UNK0C				0x0000c000
#define NV50_3D_QUERY_GET_UNIT_CROP				0x0000f000
#define NV50_3D_QUERY_GET_SYNC_COND__MASK			0x00010000
#define NV50_3D_QUERY_GET_SYNC_COND__SHIFT			16
#define NV50_3D_QUERY_GET_SYNC_COND_NEQUAL			0x00000000
#define NV50_3D_QUERY_GET_SYNC_COND_GREATER			0x00010000
#define NV50_3D_QUERY_GET_INTR					0x00100000
#define NV50_3D_QUERY_GET_TYPE__MASK				0x00800000
#define NV50_3D_QUERY_GET_TYPE__SHIFT				23
#define NV50_3D_QUERY_GET_TYPE_QUERY				0x00000000
#define NV50_3D_QUERY_GET_TYPE_COUNTER				0x00800000
#define NV50_3D_QUERY_GET_QUERY_SELECT__MASK			0x0f000000
#define NV50_3D_QUERY_GET_QUERY_SELECT__SHIFT			24
#define NV50_3D_QUERY_GET_QUERY_SELECT_ZERO			0x00000000
#define NV50_3D_QUERY_GET_QUERY_SELECT_SAMPLECNT		0x01000000
#define NV50_3D_QUERY_GET_QUERY_SELECT_STRMOUT_NO_OVERFLOW	0x02000000
#define NVA0_3D_QUERY_GET_QUERY_SELECT_STRMOUT_DROPPED_PRIMITIVES	0x03000000
#define NVA0_3D_QUERY_GET_QUERY_SELECT_STRMOUT_VERTICES		0x04000000
#define NV50_3D_QUERY_GET_QUERY_SELECT_ZCULL_STAT_UNK0		0x05000000
#define NV50_3D_QUERY_GET_QUERY_SELECT_ZCULL_STAT_UNK1		0x06000000
#define NV50_3D_QUERY_GET_QUERY_SELECT_ZCULL_STAT_UNK2		0x07000000
#define NV50_3D_QUERY_GET_QUERY_SELECT_ZCULL_STAT_UNK3		0x08000000
#define NVA0_3D_QUERY_GET_QUERY_SELECT_RT_UNK14			0x0c000000
#define NVA0_3D_QUERY_GET_QUERY_SELECT_STRMOUT_OFFSET		0x0d000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT__MASK			0x0f000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT__SHIFT			24
#define NV50_3D_QUERY_GET_COUNTER_SELECT_VFETCH_VERTICES	0x00000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_VFETCH_PRIMITIVES	0x01000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_VP_LAUNCHES		0x02000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_GP_LAUNCHES		0x03000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_GP_PRIMITIVES_OUT	0x04000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_TRANSFORM_FEEDBACK	0x05000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_GENERATED_PRIMITIVES	0x06000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_RAST_PRIMITIVES_PRECLIP	0x07000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_RAST_PRIMITIVES_POSTCLIP	0x08000000
#define NV50_3D_QUERY_GET_COUNTER_SELECT_FP_PIXELS		0x09000000
#define NV84_3D_QUERY_GET_COUNTER_SELECT_UNK0A			0x0a000000
#define NVA0_3D_QUERY_GET_COUNTER_SELECT_UNK0C			0x0c000000
#define NV50_3D_QUERY_GET_SHORT					0x10000000

#define NVA3_3D_VP_RESULT_MAP_ALT(i0)			       (0x00001b3c + 0x4*(i0))
#define NVA3_3D_VP_RESULT_MAP_ALT__ESIZE			0x00000004
#define NVA3_3D_VP_RESULT_MAP_ALT__LEN				0x00000020
#define NVA3_3D_VP_RESULT_MAP_ALT_0__MASK			0x000000ff
#define NVA3_3D_VP_RESULT_MAP_ALT_0__SHIFT			0
#define NVA3_3D_VP_RESULT_MAP_ALT_1__MASK			0x0000ff00
#define NVA3_3D_VP_RESULT_MAP_ALT_1__SHIFT			8
#define NVA3_3D_VP_RESULT_MAP_ALT_2__MASK			0x00ff0000
#define NVA3_3D_VP_RESULT_MAP_ALT_2__SHIFT			16
#define NVA3_3D_VP_RESULT_MAP_ALT_3__MASK			0xff000000
#define NVA3_3D_VP_RESULT_MAP_ALT_3__SHIFT			24

#define NVA3_3D_VERTEX_ARRAY_FETCH_ALT(i0)		       (0x00001c00 + 0x10*(i0))
#define NVA3_3D_VERTEX_ARRAY_FETCH_ALT__ESIZE			0x00000010
#define NVA3_3D_VERTEX_ARRAY_FETCH_ALT__LEN			0x00000020
#define NVA3_3D_VERTEX_ARRAY_FETCH_ALT_STRIDE__MASK		0x00000fff
#define NVA3_3D_VERTEX_ARRAY_FETCH_ALT_STRIDE__SHIFT		0
#define NVA3_3D_VERTEX_ARRAY_FETCH_ALT_ENABLE			0x20000000

#define NVA3_3D_VERTEX_ARRAY_START_HIGH_ALT(i0)		       (0x00001c04 + 0x10*(i0))
#define NVA3_3D_VERTEX_ARRAY_START_HIGH_ALT__ESIZE		0x00000010
#define NVA3_3D_VERTEX_ARRAY_START_HIGH_ALT__LEN		0x00000020

#define NVA3_3D_VERTEX_ARRAY_START_LOW_ALT(i0)		       (0x00001c08 + 0x10*(i0))
#define NVA3_3D_VERTEX_ARRAY_START_LOW_ALT__ESIZE		0x00000010
#define NVA3_3D_VERTEX_ARRAY_START_LOW_ALT__LEN			0x00000020

#define NVA3_3D_VERTEX_ARRAY_DIVISOR_ALT(i0)		       (0x00001c0c + 0x10*(i0))
#define NVA3_3D_VERTEX_ARRAY_DIVISOR_ALT__ESIZE			0x00000010
#define NVA3_3D_VERTEX_ARRAY_DIVISOR_ALT__LEN			0x00000020

#define NVA3_3D_IBLEND(i0)				       (0x00001e00 + 0x20*(i0))
#define NVA3_3D_IBLEND__ESIZE					0x00000020
#define NVA3_3D_IBLEND__LEN					0x00000008

#define NVA3_3D_IBLEND_SEPARATE_ALPHA(i0)		       (0x00001e00 + 0x20*(i0))

#define NVA3_3D_IBLEND_EQUATION_RGB(i0)			       (0x00001e04 + 0x20*(i0))
#define NVA3_3D_IBLEND_EQUATION_RGB_FUNC_ADD			0x00008006
#define NVA3_3D_IBLEND_EQUATION_RGB_MIN				0x00008007
#define NVA3_3D_IBLEND_EQUATION_RGB_MAX				0x00008008
#define NVA3_3D_IBLEND_EQUATION_RGB_FUNC_SUBTRACT		0x0000800a
#define NVA3_3D_IBLEND_EQUATION_RGB_FUNC_REVERSE_SUBTRACT	0x0000800b

#define NVA3_3D_IBLEND_FUNC_SRC_RGB(i0)			       (0x00001e08 + 0x20*(i0))

#define NVA3_3D_IBLEND_FUNC_DST_RGB(i0)			       (0x00001e0c + 0x20*(i0))

#define NVA3_3D_IBLEND_EQUATION_ALPHA(i0)		       (0x00001e10 + 0x20*(i0))
#define NVA3_3D_IBLEND_EQUATION_ALPHA_FUNC_ADD			0x00008006
#define NVA3_3D_IBLEND_EQUATION_ALPHA_MIN			0x00008007
#define NVA3_3D_IBLEND_EQUATION_ALPHA_MAX			0x00008008
#define NVA3_3D_IBLEND_EQUATION_ALPHA_FUNC_SUBTRACT		0x0000800a
#define NVA3_3D_IBLEND_EQUATION_ALPHA_FUNC_REVERSE_SUBTRACT	0x0000800b

#define NVA3_3D_IBLEND_FUNC_SRC_ALPHA(i0)		       (0x00001e14 + 0x20*(i0))

#define NVA3_3D_IBLEND_FUNC_DST_ALPHA(i0)		       (0x00001e18 + 0x20*(i0))

#define NVA3_3D_VERTEX_ARRAY_LIMIT_HIGH_ALT(i0)		       (0x00001f00 + 0x8*(i0))
#define NVA3_3D_VERTEX_ARRAY_LIMIT_HIGH_ALT__ESIZE		0x00000008
#define NVA3_3D_VERTEX_ARRAY_LIMIT_HIGH_ALT__LEN		0x00000020

#define NVA3_3D_VERTEX_ARRAY_LIMIT_LOW_ALT(i0)		       (0x00001f04 + 0x8*(i0))
#define NVA3_3D_VERTEX_ARRAY_LIMIT_LOW_ALT__ESIZE		0x00000008
#define NVA3_3D_VERTEX_ARRAY_LIMIT_LOW_ALT__LEN			0x00000020


#endif /* _HOME_SKEGGSB_GIT_ENVYTOOLS_RNNDB_NV50_3D_XML */
